/**
 * @author Maksim Kaszynski
 * base class for draggable component.
 */
DnD.Draggable = function() {};
DnD.Draggable.prototype = {

	getElement: function() {
		return $(this.id);
	},

	getDnDParams: function() {
		var elt = this.getElement();
		var attr = elt.attributes["rich:dragdndparams"];
		var dndParams;

		if (attr) {
			dndParams = attr.value.parseJSON();
		}

		attr = elt.attributes["rich:defaultdndparams"];

		if (attr) {
			if (dndParams) {
				Object.extend(dndParams, attr.value.parseJSON());
			} else {
				dndParams = attr.value.parseJSON();
			}
		}

		return dndParams;
	},

	/**
	 * @return type of draggable content
	 */
	getContentType: function() {
		return "ZZZZZ";
	},
	/**
	 * implementations are responsible for getting drag indicator
	 * @return DnD.Indicator
	 */
	getIndicator: function() {
		return null;
	},

	getOrCreateDefaultIndicator: function() {
        var dragDiv = $("_rfDefaultDragIndicator");
        if (!dragDiv) {
            dragDiv = document.createElement("div");
            dragDiv.id = "_rfDefaultDragIndicator";
            Object.extend(dragDiv, DefaultDragIndicator);
            document.body.appendChild(dragDiv);
        }
        Element.setStyle(dragDiv, {"border" : "1px dashed black"});
        return dragDiv;
    },

    setIndicator: function(event) {
		var indicator = this.getIndicator();

		if (indicator) {
			var dndParams = this.getDnDParams();

            if (this.getDraggableItems && this.getDraggableItems() > 1) {
	            if (!dndParams) {
	            	dndParams = {};
	            }

	            dndParams["draggableItems"] = this.getDraggableItems();

	            indicator.setContent("default", false, dndParams);
            } else {
	            indicator.setContent("default", true, dndParams);
            }
		}
	},

	startDrag : function(event) {
		var type = this.getContentType();
		var indicator = this.getIndicator();
		var drag = new DnD.Drag(this, indicator, type);
		DnD.startDrag(drag);
		DnD.updateDrag(event);
		this.ondragstart(event, drag);
		if (indicator) {
			indicator.show();
		}

/*		if (indicator.id.indexOf("_rfDefaultDragIndicator") != -1) {
			Position.clone(Event.element(event), indicator);
			var offSets = Position.cumulativeOffset(Event.element(event));
			indicator.removalX = Event.pointerX(event) - offSets[0];
			indicator.removalY = Event.pointerY(event) - offSets[1];
		} */

		if( this.options && this.options.ondragstart) {
			this.options.ondragstart();
		}

        // cancel out any text selections
        document.body.focus();

        // prevent text selection in IE
        this.onSelectStartHandler = document.onselectstart;
        document.onselectstart = function () { return false; };
    },
	/**
	 *
	 * @param {DnD.Drag} drag
	 */
	endDrag: function(event, drag) {
        document.onselectstart = this.onSelectStartHandler;

        var indicator = drag.indicator;
		if (indicator) {
			indicator.hide();
		}
		this.ondragend(event, drag);

		if( this.options && this.options.ondragend) {
			this.options.ondragend();
		}
    },
	/**
	 * cubclasses may define custom behavior
	 * @param {Object} drag
	 */
	ondragstart: function(event, drag) {

	},

	ondragend: function (event, drag) {

	}
};

DefaultDragIndicator = {

    setContent: function(name, single, params) {
	},

	show: function() {
        if (window.drag && window.drag.source) {
            var target = window.drag.source.getElement();

            Element.setStyle(this, {"width": Element.getWidth(target) + "px", "height": Element.getHeight(target) + "px"});

            Element.show(this);
            this.style.position = 'absolute';
        }
    },

	hide: function() {
		Element.hide(this);
		this.style.position = '';
	},

    position: function(x, y) {
/*   	if (this.id.indexOf("_rfDefaultDragIndicator") != -1 && this.removalX && this.removalY) {
				x -= (this.removalX + 5);
				y -= (this.removalY + 14);
			} */
        Element.setStyle(this, {"left": x + "px", "top": y + "px"});
    },

    accept: function() {
    	Element.setStyle(this, {"border" : "1px dashed green"});
    },

    reject: function() {
	    Element.setStyle(this, {"border" : "1px dashed red"});
    },

    leave: function() {
    	Element.setStyle(this, {"border" : "1px dashed black"});
    }
};
