/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component;

import java.io.IOException;

import javax.faces.context.FacesContext;

import org.ajax4jsf.ajax.repeat.DataVisitor;
import org.ajax4jsf.ajax.repeat.Range;

/**
 * @author Nick Belaevski - nbelaevski@exadel.com
 * created 08.12.2006
 * Wrapper class for {@link AbstractTreeDataModel} instances. Allows developer to change behaviuor 
 * easily by implementing customized {@link #getAbstractTreeDataModel()} method
 * @see PersistedDataModel for an example of customized wrapper allowing to address calls to backing model
 * or to cached one
 */
public abstract class AbstractTreeDataModelStrategyWrapper extends AbstractTreeDataModel {

	public Object getRowData() {
		return getAbstractTreeDataModel().getRowData();
	}

	public Object getRowKey() {
		return getAbstractTreeDataModel().getRowKey();
	}

	public boolean isLeaf() {
		return getAbstractTreeDataModel().isLeaf();
	}

	public boolean isRowAvailable() {
		return getAbstractTreeDataModel().isRowAvailable();
	}

	public void setRowKey(Object key) {
		getAbstractTreeDataModel().setRowKey(key);
	}

	public void walk(FacesContext context, DataVisitor dataVisitor, Range range, TreeRowKey rowKey, Object argument, boolean last) throws IOException {
		getAbstractTreeDataModel().walk(context, dataVisitor, range, rowKey, argument, last);
	}

	/**
	 * returns wrapped {@link AbstractTreeDataModel}
	 * @return wrapped {@link AbstractTreeDataModel} instance
	 */
	protected abstract AbstractTreeDataModel getAbstractTreeDataModel();
}
