/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component;

import java.io.IOException;
import java.util.HashSet;

import javax.faces.component.StateHolder;
import javax.faces.context.FacesContext;

import org.ajax4jsf.ajax.repeat.DataVisitor;
import org.ajax4jsf.ajax.repeat.Range;
import org.richfaces.component.state.TreeRange;

/**
 * @author Nick - mailto:nbelaevski@exadel.com created 08.01.2007
 * 
 */
public class CacheableTreeDataModel extends TreeDataModel implements StateHolder{

	private final class Visitor implements DataVisitor, LastElementAware {
		private final DataVisitor visitor;

		private Visitor(DataVisitor visitor) {
			this.visitor = visitor;
		}

		public void process(FacesContext context, Object rowKey, Object argument)
				throws IOException {
			treeDataModel.setRowKey(rowKey);
			if (!treeDataModel.isLeaf()) {
				leafSet.add(rowKey);
			} else {
				leafSet.remove(rowKey);
			}
			locateTreeNode((TreeRowKey) rowKey, true).setData(
					treeDataModel.getRowData());
			if (visitor != null) {
				visitor.process(context, rowKey, argument);
			}
		}

		public void resetLastElement() {
			if (visitor instanceof LastElementAware) {
				((LastElementAware) visitor).resetLastElement();
				
			}
		}

		public void setLastElement() {
			if (visitor instanceof LastElementAware) {
				((LastElementAware) visitor).setLastElement();
				
			}
		}
	}

	private TreeDataModel treeDataModel;
	private HashSet leafSet = new HashSet();

	public boolean isLeaf() {
		return !leafSet.contains(getRowKey());
	}

	public CacheableTreeDataModel() {
		super();
		setWrappedData(new TreeNodeImpl());
	}

	public void walkModel(FacesContext context, DataVisitor visitor,
			TreeRange range, TreeRowKey key, Object argument, boolean last)
			throws IOException {
		treeDataModel.walkModel(context, new Visitor(visitor), range, key,
				argument, last);
	}

	public void setTreeDataModel(TreeDataModel treeDataModel) {
		this.treeDataModel = treeDataModel;
	}

	public void walk(FacesContext context, final DataVisitor dataVisitor,
			Range range, TreeRowKey rowKey, Object argument, boolean last)
			throws IOException {
		if ((rowKey == null && ((TreeNode) getWrappedData()).isLeaf())
				|| locateTreeNode(rowKey) == null) {
			treeDataModel.walk(context, new Visitor(dataVisitor), range,
					rowKey, argument, last);
		} else {
			super.walk(context, dataVisitor, range, rowKey, argument, last);
		}
	}

	public void setRowData(Object object) {
		(locateTreeNode((TreeRowKey)getRowKey())).setData(object);
	}

	public boolean isTransient() {
		return false;
	}

	public void restoreState(FacesContext context, Object state) {
		Object[] _state = (Object[]) state;
		setWrappedData(_state[0]);
		leafSet = (HashSet) _state[1];
	}

	public Object saveState(FacesContext context) {
		Object[] state = new Object[2];
		state[0] = getWrappedData();
		state[1] = leafSet;
		return state;
	}

	public void setTransient(boolean newTransientValue) {
		if (newTransientValue) {
			throw new IllegalArgumentException(
					"ReplaceableTreeDataModel shouldn't be transient!");
		}
	}

}
