/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component;

import java.util.Iterator;
import org.richfaces.event.DataScrollerEvent;
import org.richfaces.event.DataScrollerListener;
import org.richfaces.event.DataScrollerSource;
import org.richfaces.event.DataScrollerAdapter;
import javax.faces.event.*;
import javax.faces.el.MethodBinding;

import javax.faces.FacesException;
import javax.faces.component.UIComponent;
import javax.faces.component.UIComponentBase;
import javax.faces.component.UIData;
import javax.faces.component.html.HtmlPanelGroup;
import javax.faces.context.FacesContext;


/**
 * JSF component class
 *
 */
//xxxx nick -> alex - extend UIComponentBase and 
//create event listener & event classes to define PageSwitchEvent
public abstract class UIDatascroller extends UIComponentBase implements DataScrollerSource {
	
	public static final String COMPONENT_TYPE = "org.richfaces.Datascroller";
	public static final String COMPONENT_FAMILY = "org.richfaces.Datascroller";

	public static final String FIRST_FACET_NAME = "first";

	public static final String LAST_FACET_NAME = "last";

	public static final String NEXT_FACET_NAME = "next";

	public static final String PREVIOUS_FACET_NAME = "previous";

	public static final String FAST_FORWARD_FACET_NAME = "fastforward";

	public static final String FAST_REWIND_FACET_NAME = "fastrewind";
	
	
    public void addScrollerListener(DataScrollerListener listener) {
        addFacesListener(listener);
    }

    public DataScrollerListener[] getScrollerListeners() {
        return (DataScrollerListener[]) getFacesListeners(DataScrollerListener.class);
    }

    public void removeScrollerListener(DataScrollerListener listener) {
        removeFacesListener(listener);
    }

    public void broadcast(FacesEvent event) throws AbortProcessingException {
        super.broadcast(event);
        if (event instanceof DataScrollerEvent){

            if(getScrollerListeners().length < 1){               
                addScrollerListener(new DataScrollerAdapter(getScrollerListener()));                
            }
        }

    }


	
     public abstract MethodBinding getScrollerListener();
     public abstract void setScrollerListener(MethodBinding scrollerListener);
	 public abstract void setFor(String  f);
	 public abstract String getFor();
	 public abstract int getFastStep();
	 public abstract void setFastStep(int FastStep);
	 public abstract boolean isRenderIfSinglePage();
	 public abstract void setRenderIfSinglePage(boolean renderIfSinglePage);
	 public abstract int getMaxPages();
	 public abstract void setMaxPages(int maxPages);
	 public abstract boolean isRenderCurrentAsText();
	 public abstract void setRenderCurrentAsText(boolean renderCurrentAsText);
	 public abstract String getSelectedStyleClass();
	 public abstract void setSelectedStyleClass(String  selectedStyleClass);
	 public abstract String getSelectedStyle();
	 public abstract void setSelectedStyle(String  selectedStyle);
	 public abstract String getEventsQueue();
	 public abstract void setEventsQueue(String  eventsQueue);
	 public abstract boolean isAjaxSingle();
	 public abstract void setAjaxSingle(boolean ajaxSingle);
	 public abstract int getRequestDelay();
	 public abstract void setRequestDelay(int requestDelay);
	 //public abstract boolean isImmediate();
	 //public abstract void setImmediate(boolean immediate);
	 public abstract String getTableStyleClass();
	 public abstract void setTableStyleClass(String  tableStyleClass);
	 public abstract String getStyleClass();
	 public abstract String getStyle();
	 public abstract void setStyleClass(String styleClass);
	 public abstract void setStyle(String styleClass);
     public abstract String getHandleValue();
     public abstract void setHandleValue(String handleValue);


	//TODO nick -> alex - it's better not to cache reference here - the component can be encoded
	//with different "for" values. we can cache it, but than we should set it on phase start and 
	//reset it to null on phase end:
	//public processUpdates(...) {
	//	try { allowCache = true; ... } finally { allowCache = false; _UIData = null; }
	//}	
	

	private transient UIData _UIData;

	private UIData getUIData() {
		if (_UIData == null) {
			_UIData = getDataTable();
		}
		return _UIData;
	}

	/**
	 * Finds the dataTable which id is mapped to the "for" property
	 * 
	 * @return the dataTable component
	 */
	protected UIData getDataTable() {
		String forAttribute = getFor();
		UIComponent forComp;		
		if (forAttribute == null) {
			forComp=this;
			  while((forComp = forComp.getParent())!= null) {
					if (forComp instanceof UIData) {
						setFor(forComp.getId());
						return (UIData) forComp;				
					}
				  }
				  throw new FacesException("could not dataTable for  datascroller "+ this.getId());			
		}
		else {
			forComp = findComponent(forAttribute);
		}
		if (forComp == null) {
			throw new IllegalArgumentException("could not dataTable with id '"
					+ forAttribute + "'");
		}
		else if (!(forComp instanceof UIData)) {
			throw new IllegalArgumentException("component with id '" + forAttribute
					+ "' must be of type " + UIData.class.getName() + ", not type "
					+ forComp.getClass().getName());
		}
		return (UIData) forComp;
	}

	/**
	 * Gets the index of the current page
	 * 
	 * @return the page index
	 */
	public int getPageIndex() {
		UIData uiData = getUIData();
		//xxxx nick -> alex - suppose this.getRows() would be better here
		int rows = getRows();
		if (0 == rows) {
			throw new FacesException("Missing 'rows' attribute on component '"
					+ uiData.getId() + "'");
		}

		int pageIndex;
		if (rows > 0) {
			//xxxx nick -> alex - suppose this.getFirst() would be better here
			pageIndex = getFirstRow() / rows + 1;
		}
		else {
			//TODO nick -> nick - is it valid if under 0?
			pageIndex = 0;
		}
		if (getFirstRow() % rows > 0) {
			pageIndex++;
		}
		return pageIndex;
	}

	/**
	 * Sets the page number according to the parameter recived from the
	 * commandLink
	 * 
	 * @param facetName
	 */
	public void setPage(String facetName) {

		UIData dataTable = getUIData();

		// check if facet is selected
		if (FIRST_FACET_NAME.equals(facetName)) {
			dataTable.setFirst(0);
		}
		else if (PREVIOUS_FACET_NAME.equals(facetName)) {
			int previous = dataTable.getFirst() - getRows();
			if (previous >= 0) dataTable.setFirst(previous);
		}
		else if (NEXT_FACET_NAME.equals(facetName)) {
			int next = dataTable.getFirst() + getRows();
			if (next < getRowCount()) dataTable.setFirst(next);
		}
		else if (FAST_FORWARD_FACET_NAME.equals(facetName)) {
			int fastStep = getFastStep();
			if (fastStep <= 0) fastStep = 1;
			int next = dataTable.getFirst() + getRows() * fastStep;
			int rowcount = getRowCount();
			if (next >= rowcount)
				next = (rowcount - 1) - ((rowcount - 1) % getRows());
			dataTable.setFirst(next);
		}
		else if (FAST_REWIND_FACET_NAME.equals(facetName)) {
			int fastStep = getFastStep();
			if (fastStep <= 0) fastStep = 1;
			int previous = dataTable.getFirst() - getRows() * fastStep;
			if (previous < 0) previous = 0;
			dataTable.setFirst(previous);
		}
		else if (LAST_FACET_NAME.equals(facetName)) {
			int rowcount = getRowCount();
			int rows = getRows();
			int delta = rowcount % rows;
			int first = delta > 0 && delta < rows ? rowcount - delta : rowcount
					- rows;
			if (first >= 0) {
				dataTable.setFirst(first);
			}
			else {
				dataTable.setFirst(0);
			}
		}
		// the paginator is selected
		else {
			int pageindex = Integer.parseInt(facetName);
			int pageCount = getPageCount();
			if (pageindex > pageCount) {
				pageindex = pageCount;
			}
			else if (pageindex <= 0) {
				pageindex = 1;
			}
			dataTable.setFirst(getRows() * (pageindex - 1));			
		}

	}

	/**
	 * Sets the page index
	 * 
	 * @param page number
	 */
	public void setPageIndex(int page) {
		UIData uiData = getUIData();
		int rows = getRows();
		if (0 == rows) {
			throw new FacesException("Missing 'rows' attribute on component '"
					+ uiData.getId() + "'");
		}
		uiData.setFirst(page * rows);
	}

	/**
	 * @return the page count of the uidata
	 */
	public int getPageCount() {
		//UIData uiData = getUIData();
		int rows = getRows();
		int pageCount;
		if (rows > 0) {
			pageCount = rows <= 0 ? 1 : getRowCount() / rows;
			if (getRowCount() % rows > 0) {
				pageCount++;
			}
		}
		else {
			rows = 1;
			pageCount = 1;
		}
		return pageCount;
	}

	/**
	 * @return int
	 */
	public int getRowCount() {
		//TODO nick -> alex - scrollable models can return -1 here
		//let's implement "dychotomic" discovery
		// setPage(1)... if isPageAvailable() setPage(2) then 4, 8, etc. 
		// setPage() { setRowIndex(pageIdx * rows); }
		// isPageAvailable() { return isRowAvailable() }
		return getUIData().getRowCount();
	}

	
	
	/**
	 * @return int
	 */
	public int getRows() {
		int row=0;
		row=getUIData().getRows();
		if (row==0){
		  //if (getRowCount()>=2){
		  //	  row=2;
		  //	  
		  //}
		  //else{
			  row=getRowCount();
			  
		  //}
			  
		}
		
		return row;
		//return getUIData().getRowCount();
		
	}

	// facet getter methods
	public UIComponent getFirst() {
		return (UIComponent) getFacet(FIRST_FACET_NAME);
	}

	public UIComponent getLast() {
		return (UIComponent) getFacet(LAST_FACET_NAME);
	}

	public UIComponent getNext() {
		return (UIComponent) getFacet(NEXT_FACET_NAME);
	}

	public UIComponent getFastForward() {
		return (UIComponent) getFacet(FAST_FORWARD_FACET_NAME);
	}

	public UIComponent getFastRewind() {
		return (UIComponent) getFacet(FAST_REWIND_FACET_NAME);
	}

	public UIComponent getPrevious() {
		return (UIComponent) getFacet(PREVIOUS_FACET_NAME);
	}

	/**
	 * @return int
	 */
	public int getFirstRow() {
		return getUIData().getFirst();
	}


	
	
	
	
	
	
/*
	public Object saveState(FacesContext context) {
		Object values[] = new Object[17];
		values[0] = super.saveState(context);
		values[1] = _for;
		values[2] = tableStyleClass;
		values[3] = tableStyle;
		values[4] = selectedStyleClass;
		values[5] = selectedStyle;
		values[6] = styleClass;
		values[7] = style;
		values[8] = maxPages;
		values[9] = renderIfSinglePage;
		values[10] = fastStep;
		values[11] = immediate;
		values[12] = ignoreDupResponses;
		values[13] = eventsQueue;
		values[14] = requestDelay;
		values[15] = ajaxSingle;
		values[16] = renderCurrentAsText;
		return values;
	}

	public void restoreState(FacesContext context, Object state) {
		Object values[] = (Object[]) state;
		super.restoreState(context, values[0]);
		_for = (String) values[1];
		tableStyleClass = (String) values[2];
		tableStyle = (String) values[3];
		selectedStyleClass = (String) values[4];
		selectedStyle = (String) values[5];
		styleClass = (String) values[6];
		style = (String) values[7];
		maxPages = (Integer) values[8];
		renderIfSinglePage = (Boolean) values[9];
		fastStep = (Integer) values[10];
		immediate = (Boolean) values[11];
		ignoreDupResponses = (Boolean) values[12];
		eventsQueue = (String) values[13];
		requestDelay = (Integer) values[14];
		ajaxSingle = (Boolean) values[15];
		renderCurrentAsText = (Boolean) values[16];
	}
*/

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	//public String getRendererType() {
	//	return RENDERER_TYPE;
	//}


}
