/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component;

import org.ajax4jsf.framework.ajax.AjaxComponent;
import org.ajax4jsf.framework.ajax.AjaxContext;
import org.ajax4jsf.framework.ajax.AjaxEvent;
import org.ajax4jsf.framework.renderer.AjaxRendererUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.faces.component.UIData;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.el.MethodBinding;
import javax.faces.event.AbortProcessingException;
import javax.faces.event.FacesEvent;
import javax.faces.event.PhaseId;


/**
 * @author shura (latest modification by $Author: alexsmirnov $)
 * @version $Revision: 1.5 $ $Date: 2007/03/01 22:37:50 $
 */
public abstract class UISuggestionBox extends UIData implements AjaxComponent {

    private static Log log = LogFactory.getLog(UISuggestionBox.class);

    private static final String COMPONENT_TYPE = "org.richfaces.SuggestionBox";

    private static final String COMPONENT_FAMILY = "org.richfaces.SuggestionBox";


    private transient boolean submitted = false;

    public abstract String getFor();

    public abstract void setFor(String __for);

    public abstract MethodBinding getSuggestionAction();

    public abstract void setSuggestionAction(MethodBinding action);

    public abstract Converter getConverter();

    public abstract void setConverter(Converter converter);

    /**
     * @return
     */
    public abstract String getRowClasses();

    public abstract void setRowClasses(String rowClasses);

    /**
     * @return
     */
    public abstract String getSelectValueClass();

    public abstract void setSelectValueClass(String value);

    /**
     * @return
     */
    public abstract String getBorder();
//

    public abstract void setCellpadding(String value);

    public abstract String getCellpadding();

    public abstract void setBorder(String value);

    public abstract boolean isImmediate();

    public abstract void setImmediate(boolean value);

    public abstract boolean isSelfRendered();

    public abstract void setSelfRendered(boolean value);

    /**
     * @return
     */
    public abstract String getEntryClass();

    public abstract void setEntryClass(String value);

    public boolean isSubmitted() {
        return submitted;
    }

    public void setSubmitted(boolean submitted) {
        this.submitted = submitted;
    }

    /* (non-Javadoc)
      * @see javax.faces.component.UIComponentBase#queueEvent(javax.faces.event.FacesEvent)
      */
    public void queueEvent(FacesEvent event) {
        if (event instanceof SuggestionEvent) {
            if (isImmediate()) {
                event.setPhaseId(PhaseId.APPLY_REQUEST_VALUES);
            } else if (isBypassUpdates()) {
                event.setPhaseId(PhaseId.PROCESS_VALIDATIONS);
            } else {
                event.setPhaseId(PhaseId.INVOKE_APPLICATION);
            }
        }
        super.queueEvent(event);
    }


    /* (non-Javadoc)
      * @see javax.faces.component.UIData#broadcast(javax.faces.event.FacesEvent)
      */
    public void broadcast(FacesEvent event) throws AbortProcessingException {
        super.broadcast(event);
        if (event instanceof SuggestionEvent) {
            SuggestionEvent suggestionEvent = (SuggestionEvent) event;
			Object value = suggestionEvent.getSubmittedValue();
            MethodBinding suggestingAction = getSuggestionAction();
            if (null != suggestingAction ) {
                // TODO - use converter
                setValue(suggestingAction.invoke(getFacesContext(), new Object[]{value}));
                getFacesContext().renderResponse();
            }
        } else if (event instanceof AjaxEvent) {
            FacesContext context = getFacesContext();
            AjaxRendererUtils.addRegionsFromComponent(this, context);
            AjaxRendererUtils.addRegionByName(context, this, this.getId());
            setSubmitted(true);
            if (isSelfRendered()) {
                AjaxContext.getCurrentInstance(context).renderSubmittedAjaxRegion(context, true);
            }
        }
    }


}
