/**
 * 
 */
package org.richfaces.component;

import java.util.Map;

import javax.faces.component.UIComponent;
import javax.faces.component.UIComponentBase;
import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;
import javax.faces.event.AbortProcessingException;
import javax.faces.event.FacesEvent;

import org.ajax4jsf.dnd.Draggable;
import org.ajax4jsf.dnd.Dropzone;
import org.ajax4jsf.dnd.event.DragListener;
import org.ajax4jsf.dnd.event.DropListener;
import org.ajax4jsf.framework.ajax.AjaxEvent;
import org.ajax4jsf.framework.renderer.AjaxRendererUtils;
import org.richfaces.component.events.NodeExpandedListener;
import org.richfaces.component.events.NodeSelectedListener;
import org.richfaces.component.events.TreeEvents;

/**
 * @author Nick Belaevski - nbelaevski@exadel.com created 22.11.2006 Component
 *         class providing concrete representation for tree node
 */

public abstract class UITreeNode extends UIComponentBase implements
TreeListenerEventsProducer, Draggable, Dropzone {

	private String dragType;
	private Object acceptedTypes;

	public static final String COMPONENT_TYPE = "org.richfaces.TreeNode";

	public static final String COMPONENT_FAMILY = "org.richfaces.TreeNode";

	/**
	 * Attribute name to indicate if this tree node is a virtual
	 * {@link UITreeNode} providing default representation for node. Default
	 * tree node representation should use attributes of its parent
	 * {@link UITree} component
	 */
	protected final static String DEFAULT_NODE_FACE_ATTRIBUTE_NAME = "#defaultNodeFace";

	public abstract String getType();

	public abstract void setType(String type);

	public abstract String getIcon();

	public abstract void setIcon(String icon);

	public abstract String getIconExpanded();

	public abstract void setIconExpanded(String icon);

	public abstract String getIconCollapsed();

	public abstract void setIconCollapsed(String icon);

	public abstract String getIconLeaf();

	public abstract void setIconLeaf(String icon);

	public abstract void setAjaxSubmitSelection(String ajaxSubmitSelection);

	public abstract String getAjaxSubmitSelection();

	public abstract void setHighlightedClass(String selectedClass);

	public abstract String getHighlightedClass();

	public abstract void setSelectedClass(String selectedClass);

	public abstract String getSelectedClass();

	public boolean hasAjaxSubmitSelection() {
		if ("inherit".equals(getAjaxSubmitSelection())) {
			return getUITree().isAjaxSubmitSelection();
		} else if ("true".equals(getAjaxSubmitSelection())) {
			return true;
		} else if ("false".equals(getAjaxSubmitSelection())) {
			return false;
		} else {
			throw new IllegalArgumentException(
			"Property \"ajaxSubmitSelection\" should be \"inherit\", \"true\" or \"false\".");
		}

	}


	public void broadcast(FacesEvent event) throws AbortProcessingException {
		super.broadcast(event);

		FacesContext context = getFacesContext();
		TreeEvents.invokeListenerBindings(this, event, context);

		if (event instanceof AjaxEvent) {
			AjaxRendererUtils.addRegionsFromComponent(this, getFacesContext());
		}
	}

	public void addChangeExpandListener(NodeExpandedListener listener) {
		addFacesListener(listener);
	}

	public void addNodeSelectListener(NodeSelectedListener listener) {
		addFacesListener(listener);
	}

	/**
	 * Finds direct parent {@link UITree} component or throws
	 * {@link ClassCastException} if parent is not {@link UITree}
	 * 
	 * @return {@link UITree} instance
	 * @throws ClassCastException
	 */
	public UITree getUITree() throws ClassCastException {
		UIComponent parent = getParent();
		if (parent == null) {
			return null;
		}
		
		if (parent instanceof UITree) {
			return (UITree) parent;

		} else {
			throw new ClassCastException("Parent should be UITree.");
		}
	}

	public UIComponent getComponent() {
		return this;
	}

	public void addDropListener(DropListener listener) {
		addFacesListener(listener);
	}

	public DropListener[] getDropListeners() {
		return (DropListener[]) getFacesListeners(DropListener.class);
	}

	public void removeDropListener(DropListener listener) {
		removeFacesListener(listener);
	}


	public void addDragListener(DragListener listener) {
		addFacesListener(listener);
	}

	public DragListener[] getDragListeners() {
		return (DragListener[]) getFacesListeners(DragListener.class);
	}

	public void removeDragListener(DragListener listener) {
		removeFacesListener(listener);
	}

	public Map getAttributes() {
		Map map = super.getAttributes();

		if (Boolean.TRUE.equals(map.get(DEFAULT_NODE_FACE_ATTRIBUTE_NAME))) {
			return getUITree().getAttributes();
		}

		return map;
	}

	/*
	 * Key of a drag object. It's used to define a necessity of processing the current dragged element on the drop zone side
	 * Getter for dragType
	 * @return dragType value from local variable or value bindings
	 */
	public String getDragType(  ){
		if (null != this.dragType)
		{
			return this.dragType;
		}
		ValueBinding vb = getValueBinding("dragType");
		if (null != vb){
			return (String)vb.getValue(getFacesContext());
		} else {
			UITree tree = getUITree();
			if (tree != null) {
				return tree.getDragType();
			}

			return null;
		}
	}
	/*
	 * Key of a drag object. It's used to define a necessity of processing the current dragged element on the drop zone side
	 * Setter for dragType
	 * @param dragType - new value
	 */
	public void setDragType( String  __dragType ){
		this.dragType = __dragType;
	}
	/*
	 * List of drag types to be processd by the current drop zone.
	 * Getter for acceptedTypes
	 * @return acceptedTypes value from local variable or value bindings
	 */
	public Object getAcceptedTypes(  ){
		if (null != this.acceptedTypes)
		{
			return this.acceptedTypes;
		}
		ValueBinding vb = getValueBinding("acceptedTypes");
		if (null != vb){
			return (Object)vb.getValue(getFacesContext());
		} else {
			UITree tree = getUITree();
			if (tree != null) {
				return tree.getAcceptedTypes();
			}

			return null;
		}
	}
	/*
	 * List of drag types to be processd by the current drop zone.
	 * Setter for acceptedTypes
	 * @param acceptedTypes - new value
	 */
	public void setAcceptedTypes( Object  __acceptedTypes ){
		this.acceptedTypes = __acceptedTypes;
	}

	public Object saveState(FacesContext context) {
		Object superState = super.saveState(context);
		Object[] state = new Object[3];
		state[0] = superState;
		state[1] = this.dragType;
		state[2] = this.acceptedTypes;
		
		return state;
	}
	
	public void restoreState(FacesContext context, Object state) {
		Object[] _state = (Object[]) state;
		super.restoreState(context, _state[0]);
		this.dragType = (String) _state[1];
		this.acceptedTypes = _state[2];
	}
}
