/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UIColumn ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.Column
 * Component-Family org.richfaces.Column
  	 * Renderer-Type org.richfaces.ColumnRenderer
  	 * 
 */
 public class HtmlColumn extends org.richfaces.component.UIColumn {

  public static final String COMPONENT_TYPE = "org.richfaces.Column";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlColumn (){
  	  	setRendererType("org.richfaces.ColumnRenderer");
  	  }

// Component properties fields
  	/**
	 * lang
	 * Code describing the language used in the generated markup for this component
	 */
	 	 private String  _lang = null; /* Default is null*/
	 	  	/**
	 * title
	 * Advisory title information about markup elements generated for this component
	 */
	 	 private String  _title = null; /* Default is null*/
	 	   	/**
	 * colspan
	 * 
	 */
	 	 private int  _colspan = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what colspan is set.
	 */
	 private boolean _colspanSet = false;	
	 	  	/**
	 * headerClass
	 * 
	 */
	 	 private String  _headerClass = null; /* Default is null*/
	 	   	/**
	 * footerClass
	 * 
	 */
	 	 private String  _footerClass = null; /* Default is null*/
	 	   	/**
	 * dir
	 * Alternate textual description of the element rendered by this component
	 */
	 	 private String  _dir = null; /* Default is null*/
	 	  	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * breakBefore
	 * 
	 */
	 	 private boolean  _breakBefore = false;		
	/**
	 * Flag indicated what breakBefore is set.
	 */
	 private boolean _breakBeforeSet = false;	
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	   	/**
	 * rowspan
	 * 
	 */
	 	 private int  _rowspan = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what rowspan is set.
	 */
	 private boolean _rowspanSet = false;	
	 	 
// Getters-setters
  	/*
	 * Code describing the language used in the generated markup for this component
	 * Setter for lang
	 * @param lang - new value
	 */
	 public void setLang( String  __lang ){
		this._lang = __lang;
	 	 }


	/*
	 * Code describing the language used in the generated markup for this component
	 * Getter for lang
	 * @return lang value from local variable or value bindings
	 */
	 public String getLang(  ){
	         if (null != this._lang)
        {
            return this._lang;
        	    }
        ValueBinding vb = getValueBinding("lang");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Advisory title information about markup elements generated for this component
	 * Setter for title
	 * @param title - new value
	 */
	 public void setTitle( String  __title ){
		this._title = __title;
	 	 }


	/*
	 * Advisory title information about markup elements generated for this component
	 * Getter for title
	 * @return title value from local variable or value bindings
	 */
	 public String getTitle(  ){
	         if (null != this._title)
        {
            return this._title;
        	    }
        ValueBinding vb = getValueBinding("title");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * 
	 * Setter for colspan
	 * @param colspan - new value
	 */
	 public void setColspan( int  __colspan ){
		this._colspan = __colspan;
	 		this._colspanSet = true;
	 	 }


	/*
	 * 
	 * Getter for colspan
	 * @return colspan value from local variable or value bindings
	 */
	 public int getColspan(  ){
	 		 if(this._colspanSet){
			return this._colspan;
		 }
    	ValueBinding vb = getValueBinding("colspan");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._colspan;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._colspan);
    	}
	 	 }
	   	/*
	 * 
	 * Setter for headerClass
	 * @param headerClass - new value
	 */
	 public void setHeaderClass( String  __headerClass ){
		this._headerClass = __headerClass;
	 	 }


	/*
	 * 
	 * Getter for headerClass
	 * @return headerClass value from local variable or value bindings
	 */
	 public String getHeaderClass(  ){
	         if (null != this._headerClass)
        {
            return this._headerClass;
        	    }
        ValueBinding vb = getValueBinding("headerClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * 
	 * Setter for footerClass
	 * @param footerClass - new value
	 */
	 public void setFooterClass( String  __footerClass ){
		this._footerClass = __footerClass;
	 	 }


	/*
	 * 
	 * Getter for footerClass
	 * @return footerClass value from local variable or value bindings
	 */
	 public String getFooterClass(  ){
	         if (null != this._footerClass)
        {
            return this._footerClass;
        	    }
        ValueBinding vb = getValueBinding("footerClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Alternate textual description of the element rendered by this component
	 * Setter for dir
	 * @param dir - new value
	 */
	 public void setDir( String  __dir ){
		this._dir = __dir;
	 	 }


	/*
	 * Alternate textual description of the element rendered by this component
	 * Getter for dir
	 * @return dir value from local variable or value bindings
	 */
	 public String getDir(  ){
	         if (null != this._dir)
        {
            return this._dir;
        	    }
        ValueBinding vb = getValueBinding("dir");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for breakBefore
	 * @param breakBefore - new value
	 */
	 public void setBreakBefore( boolean  __breakBefore ){
		this._breakBefore = __breakBefore;
	 		this._breakBeforeSet = true;
	 	 }


	/*
	 * 
	 * Getter for breakBefore
	 * @return breakBefore value from local variable or value bindings
	 */
	 public boolean isBreakBefore(  ){
	 		 if(this._breakBeforeSet){
			return this._breakBefore;
		 }
    	ValueBinding vb = getValueBinding("breakBefore");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._breakBefore;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._breakBefore);
    	}
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * 
	 * Setter for rowspan
	 * @param rowspan - new value
	 */
	 public void setRowspan( int  __rowspan ){
		this._rowspan = __rowspan;
	 		this._rowspanSet = true;
	 	 }


	/*
	 * 
	 * Getter for rowspan
	 * @return rowspan value from local variable or value bindings
	 */
	 public int getRowspan(  ){
	 		 if(this._rowspanSet){
			return this._rowspan;
		 }
    	ValueBinding vb = getValueBinding("rowspan");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._rowspan;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._rowspan);
    	}
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.Column";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[14];
        values[0] = super.saveState(context);
  	 	          values[1] = _lang;
	   	 	
  	 	          values[2] = _title;
	   	 	
   	        values[3] = new Integer(_colspan);
	   	   values[4] = Boolean.valueOf(_colspanSet);	
	   	 	
  	 	          values[5] = _headerClass;
	   	 	
   	 	          values[6] = _footerClass;
	   	 	
   	 	          values[7] = _dir;
	   	 	
  	 	          values[8] = _styleClass;
	   	 	
  	        values[9] = new Boolean(_breakBefore);
	   	   values[10] = Boolean.valueOf(_breakBeforeSet);	
	   	 	
  	 	          values[11] = _style;
	   	 	
   	        values[12] = new Integer(_rowspan);
	   	   values[13] = Boolean.valueOf(_rowspanSet);	
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	 	          _lang = (String)values[1] ;
	   	 	
  	 	          _title = (String)values[2] ;
	   	 	
   	        _colspan = ((Integer)values[3]).intValue();
	   	   _colspanSet = ((Boolean)values[4]).booleanValue();	
	   	 	
  	 	          _headerClass = (String)values[5] ;
	   	 	
   	 	          _footerClass = (String)values[6] ;
	   	 	
   	 	          _dir = (String)values[7] ;
	   	 	
  	 	          _styleClass = (String)values[8] ;
	   	 	
  	        _breakBefore = ((Boolean)values[9]).booleanValue();
	   	   _breakBeforeSet = ((Boolean)values[10]).booleanValue();	
	   	 	
  	 	          _style = (String)values[11] ;
	   	 	
   	        _rowspan = ((Integer)values[12]).intValue();
	   	   _rowspanSet = ((Boolean)values[13]).booleanValue();	
	   	 	
 	
		
	}	
// Utilites

}