/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import java.lang.Integer ;
import org.richfaces.component.UIDataFltrSlider ;
import javax.faces.el.MethodBinding ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.DataFilterSlider
 * Component-Family org.richfaces.DataFilterSlider
  	 * Renderer-Type org.richfaces.DataFilterSliderRenderer
  	 * A slider-based action component used for filtering table data.
 */
 public class HtmlDataFilterSlider extends org.richfaces.component.UIDataFltrSlider {

  public static final String COMPONENT_TYPE = "org.richfaces.DataFilterSlider";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlDataFilterSlider (){
  	  	setRendererType("org.richfaces.DataFilterSliderRenderer");
  	  }

// Component properties fields
 	/**
	 * width
	 * Width of the slider control
	 */
	 	 private String  _width = null; /* Default is "200px"*/
	 	  	/**
	 * filterBy
	 * A getter of an object member required to compare a slider value to. This is a
                value that is used in results filtering.
	 */
	 	 private String  _filterBy = null; /* Default is null*/
	 	   	/**
	 * startRange
	 * A slider begin point
	 */
	 	 private Integer  _startRange = null; /* Default is null*/
	 	    	/**
	 * endRange
	 * A slider end point.
	 */
	 	 private Integer  _endRange = null; /* Default is null*/
	 	   	/**
	 * storeResults
	 * Specifies if the component will store a UIData object (your table rows) in session.
	 */
	 	 private boolean  _storeResults = false;		
	/**
	 * Flag indicated what storeResults is set.
	 */
	 private boolean _storeResultsSet = false;	
	 	  	/**
	 * styleClass
	 * The styleClass for the container div surrounding the component.
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * onSlide
	 * If the slider value changes must submit a form, onSlide or OnChange can be true.
	 */
	 	 private boolean  _onSlide = false;		
	/**
	 * Flag indicated what onSlide is set.
	 */
	 private boolean _onSlideSet = false;	
	 	  	/**
	 * handleValue
	 * Current handle value
	 */
	 	 private Integer  _handleValue = null; /* Default is null*/
	 	  	/**
	 * sliderListener
	 * sliderListener
	 */
	 	 private MethodBinding  _sliderListener = null; /* Default is null*/
	 	  	/**
	 * trackStyleClass
	 * The trackStyleClass for a background div
	 */
	 	 private String  _trackStyleClass = null; /* Default is null*/
	 	  	/**
	 * handleStyleClass
	 * The handleStyleClass for a handle.
	 */
	 	 private String  _handleStyleClass = null; /* Default is null*/
	 	  	/**
	 * for
	 * The component using UIData (datatable id)
	 */
	 	 private String  _for = null; /* Default is null*/
	 	   	/**
	 * increment
	 * Amount to which a handle on each slide/move should be incremented
	 */
	 	 private Integer  _increment = null; /* Default is null*/
	 	  	/**
	 * rangeStyleClass
	 * The rangeStyleClass for the background div showing a full range
	 */
	 	 private String  _rangeStyleClass = null; /* Default is null*/
	 	  	/**
	 * fieldStyleClass
	 * The styleClass for input that displays the value : 'manualInput' must
                be true
	 */
	 	 private String  _fieldStyleClass = null; /* Default is null*/
	 	  	/**
	 * trailer
	 * It shows or hides a trailer following a handle
	 */
	 	 private boolean  _trailer = false;		
	/**
	 * Flag indicated what trailer is set.
	 */
	 private boolean _trailerSet = false;	
	 	  	/**
	 * manualInput
	 * False value for this attribute makes text field "read-only" and "hidden".
                Hence, the value can be changed only from a handle.
	 */
	 	 private boolean  _manualInput = true;		
	/**
	 * Flag indicated what manualInput is set.
	 */
	 private boolean _manualInputSet = false;	
	 	   	/**
	 * forValRef
	 * This is a string which is used in a value attribute of the datatable. It is used for resetting
                the datatable back to the original list provided by a backing bean.
	 */
	 	 private String  _forValRef = null; /* Default is null*/
	 	  	/**
	 * onChange
	 * If the slider value changes must submit a form, onSlide or OnChange can be true.
	 */
	 	 private boolean  _onChange = false;		
	/**
	 * Flag indicated what onChange is set.
	 */
	 private boolean _onChangeSet = false;	
	 	  	/**
	 * trailerStyleClass
	 * The trailerStyleClass for a div following a handle.
	 */
	 	 private String  _trailerStyleClass = null; /* Default is null*/
	 	  
// Getters-setters
 	/*
	 * Width of the slider control
	 * Setter for width
	 * @param width - new value
	 */
	 public void setWidth( String  __width ){
		this._width = __width;
	 	 }


	/*
	 * Width of the slider control
	 * Getter for width
	 * @return width value from local variable or value bindings
	 */
	 public String getWidth(  ){
	         if (null != this._width)
        {
            return this._width;
        	    }
        ValueBinding vb = getValueBinding("width");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "200px";
        }
	 	 }
	   	/*
	 * A getter of an object member required to compare a slider value to. This is a
                value that is used in results filtering.
	 * Setter for filterBy
	 * @param filterBy - new value
	 */
	 public void setFilterBy( String  __filterBy ){
		this._filterBy = __filterBy;
	 	 }


	/*
	 * A getter of an object member required to compare a slider value to. This is a
                value that is used in results filtering.
	 * Getter for filterBy
	 * @return filterBy value from local variable or value bindings
	 */
	 public String getFilterBy(  ){
	         if (null != this._filterBy)
        {
            return this._filterBy;
        	    }
        ValueBinding vb = getValueBinding("filterBy");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * A slider begin point
	 * Setter for startRange
	 * @param startRange - new value
	 */
	 public void setStartRange( Integer  __startRange ){
		this._startRange = __startRange;
	 	 }


	/*
	 * A slider begin point
	 * Getter for startRange
	 * @return startRange value from local variable or value bindings
	 */
	 public Integer getStartRange(  ){
	         if (null != this._startRange)
        {
            return this._startRange;
        	    }
        ValueBinding vb = getValueBinding("startRange");
        if (null != vb){
            return (Integer)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * A slider end point.
	 * Setter for endRange
	 * @param endRange - new value
	 */
	 public void setEndRange( Integer  __endRange ){
		this._endRange = __endRange;
	 	 }


	/*
	 * A slider end point.
	 * Getter for endRange
	 * @return endRange value from local variable or value bindings
	 */
	 public Integer getEndRange(  ){
	         if (null != this._endRange)
        {
            return this._endRange;
        	    }
        ValueBinding vb = getValueBinding("endRange");
        if (null != vb){
            return (Integer)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Specifies if the component will store a UIData object (your table rows) in session.
	 * Setter for storeResults
	 * @param storeResults - new value
	 */
	 public void setStoreResults( boolean  __storeResults ){
		this._storeResults = __storeResults;
	 		this._storeResultsSet = true;
	 	 }


	/*
	 * Specifies if the component will store a UIData object (your table rows) in session.
	 * Getter for storeResults
	 * @return storeResults value from local variable or value bindings
	 */
	 public boolean isStoreResults(  ){
	 		 if(this._storeResultsSet){
			return this._storeResults;
		 }
    	ValueBinding vb = getValueBinding("storeResults");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._storeResults;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._storeResults);
    	}
	 	 }
	   	/*
	 * The styleClass for the container div surrounding the component.
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * The styleClass for the container div surrounding the component.
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If the slider value changes must submit a form, onSlide or OnChange can be true.
	 * Setter for onSlide
	 * @param onSlide - new value
	 */
	 public void setOnSlide( boolean  __onSlide ){
		this._onSlide = __onSlide;
	 		this._onSlideSet = true;
	 	 }


	/*
	 * If the slider value changes must submit a form, onSlide or OnChange can be true.
	 * Getter for onSlide
	 * @return onSlide value from local variable or value bindings
	 */
	 public boolean isOnSlide(  ){
	 		 if(this._onSlideSet){
			return this._onSlide;
		 }
    	ValueBinding vb = getValueBinding("onSlide");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._onSlide;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._onSlide);
    	}
	 	 }
	   	/*
	 * Current handle value
	 * Setter for handleValue
	 * @param handleValue - new value
	 */
	 public void setHandleValue( Integer  __handleValue ){
		this._handleValue = __handleValue;
	 	 }


	/*
	 * Current handle value
	 * Getter for handleValue
	 * @return handleValue value from local variable or value bindings
	 */
	 public Integer getHandleValue(  ){
	         if (null != this._handleValue)
        {
            return this._handleValue;
        	    }
        ValueBinding vb = getValueBinding("handleValue");
        if (null != vb){
            return (Integer)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * sliderListener
	 * Setter for sliderListener
	 * @param sliderListener - new value
	 */
	 public void setSliderListener( MethodBinding  __sliderListener ){
		this._sliderListener = __sliderListener;
	 	 }


	/*
	 * sliderListener
	 * Getter for sliderListener
	 * @return sliderListener value from local variable or value bindings
	 */
	 public MethodBinding getSliderListener(  ){
	         if (null != this._sliderListener)
        {
            return this._sliderListener;
                } else {
            return null;
        }
	 	 }
	   	/*
	 * The trackStyleClass for a background div
	 * Setter for trackStyleClass
	 * @param trackStyleClass - new value
	 */
	 public void setTrackStyleClass( String  __trackStyleClass ){
		this._trackStyleClass = __trackStyleClass;
	 	 }


	/*
	 * The trackStyleClass for a background div
	 * Getter for trackStyleClass
	 * @return trackStyleClass value from local variable or value bindings
	 */
	 public String getTrackStyleClass(  ){
	         if (null != this._trackStyleClass)
        {
            return this._trackStyleClass;
        	    }
        ValueBinding vb = getValueBinding("trackStyleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The handleStyleClass for a handle.
	 * Setter for handleStyleClass
	 * @param handleStyleClass - new value
	 */
	 public void setHandleStyleClass( String  __handleStyleClass ){
		this._handleStyleClass = __handleStyleClass;
	 	 }


	/*
	 * The handleStyleClass for a handle.
	 * Getter for handleStyleClass
	 * @return handleStyleClass value from local variable or value bindings
	 */
	 public String getHandleStyleClass(  ){
	         if (null != this._handleStyleClass)
        {
            return this._handleStyleClass;
        	    }
        ValueBinding vb = getValueBinding("handleStyleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The component using UIData (datatable id)
	 * Setter for for
	 * @param for - new value
	 */
	 public void setFor( String  __for ){
		this._for = __for;
	 	 }


	/*
	 * The component using UIData (datatable id)
	 * Getter for for
	 * @return for value from local variable or value bindings
	 */
	 public String getFor(  ){
	         if (null != this._for)
        {
            return this._for;
        	    }
        ValueBinding vb = getValueBinding("for");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Amount to which a handle on each slide/move should be incremented
	 * Setter for increment
	 * @param increment - new value
	 */
	 public void setIncrement( Integer  __increment ){
		this._increment = __increment;
	 	 }


	/*
	 * Amount to which a handle on each slide/move should be incremented
	 * Getter for increment
	 * @return increment value from local variable or value bindings
	 */
	 public Integer getIncrement(  ){
	         if (null != this._increment)
        {
            return this._increment;
        	    }
        ValueBinding vb = getValueBinding("increment");
        if (null != vb){
            return (Integer)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The rangeStyleClass for the background div showing a full range
	 * Setter for rangeStyleClass
	 * @param rangeStyleClass - new value
	 */
	 public void setRangeStyleClass( String  __rangeStyleClass ){
		this._rangeStyleClass = __rangeStyleClass;
	 	 }


	/*
	 * The rangeStyleClass for the background div showing a full range
	 * Getter for rangeStyleClass
	 * @return rangeStyleClass value from local variable or value bindings
	 */
	 public String getRangeStyleClass(  ){
	         if (null != this._rangeStyleClass)
        {
            return this._rangeStyleClass;
        	    }
        ValueBinding vb = getValueBinding("rangeStyleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The styleClass for input that displays the value : 'manualInput' must
                be true
	 * Setter for fieldStyleClass
	 * @param fieldStyleClass - new value
	 */
	 public void setFieldStyleClass( String  __fieldStyleClass ){
		this._fieldStyleClass = __fieldStyleClass;
	 	 }


	/*
	 * The styleClass for input that displays the value : 'manualInput' must
                be true
	 * Getter for fieldStyleClass
	 * @return fieldStyleClass value from local variable or value bindings
	 */
	 public String getFieldStyleClass(  ){
	         if (null != this._fieldStyleClass)
        {
            return this._fieldStyleClass;
        	    }
        ValueBinding vb = getValueBinding("fieldStyleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * It shows or hides a trailer following a handle
	 * Setter for trailer
	 * @param trailer - new value
	 */
	 public void setTrailer( boolean  __trailer ){
		this._trailer = __trailer;
	 		this._trailerSet = true;
	 	 }


	/*
	 * It shows or hides a trailer following a handle
	 * Getter for trailer
	 * @return trailer value from local variable or value bindings
	 */
	 public boolean isTrailer(  ){
	 		 if(this._trailerSet){
			return this._trailer;
		 }
    	ValueBinding vb = getValueBinding("trailer");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._trailer;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._trailer);
    	}
	 	 }
	   	/*
	 * False value for this attribute makes text field "read-only" and "hidden".
                Hence, the value can be changed only from a handle.
	 * Setter for manualInput
	 * @param manualInput - new value
	 */
	 public void setManualInput( boolean  __manualInput ){
		this._manualInput = __manualInput;
	 		this._manualInputSet = true;
	 	 }


	/*
	 * False value for this attribute makes text field "read-only" and "hidden".
                Hence, the value can be changed only from a handle.
	 * Getter for manualInput
	 * @return manualInput value from local variable or value bindings
	 */
	 public boolean isManualInput(  ){
	 		 if(this._manualInputSet){
			return this._manualInput;
		 }
    	ValueBinding vb = getValueBinding("manualInput");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._manualInput;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._manualInput);
    	}
	 	 }
	    	/*
	 * This is a string which is used in a value attribute of the datatable. It is used for resetting
                the datatable back to the original list provided by a backing bean.
	 * Setter for forValRef
	 * @param forValRef - new value
	 */
	 public void setForValRef( String  __forValRef ){
		this._forValRef = __forValRef;
	 	 }


	/*
	 * This is a string which is used in a value attribute of the datatable. It is used for resetting
                the datatable back to the original list provided by a backing bean.
	 * Getter for forValRef
	 * @return forValRef value from local variable or value bindings
	 */
	 public String getForValRef(  ){
	         if (null != this._forValRef)
        {
            return this._forValRef;
        	    }
        ValueBinding vb = getValueBinding("forValRef");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If the slider value changes must submit a form, onSlide or OnChange can be true.
	 * Setter for onChange
	 * @param onChange - new value
	 */
	 public void setOnChange( boolean  __onChange ){
		this._onChange = __onChange;
	 		this._onChangeSet = true;
	 	 }


	/*
	 * If the slider value changes must submit a form, onSlide or OnChange can be true.
	 * Getter for onChange
	 * @return onChange value from local variable or value bindings
	 */
	 public boolean isOnChange(  ){
	 		 if(this._onChangeSet){
			return this._onChange;
		 }
    	ValueBinding vb = getValueBinding("onChange");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._onChange;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._onChange);
    	}
	 	 }
	   	/*
	 * The trailerStyleClass for a div following a handle.
	 * Setter for trailerStyleClass
	 * @param trailerStyleClass - new value
	 */
	 public void setTrailerStyleClass( String  __trailerStyleClass ){
		this._trailerStyleClass = __trailerStyleClass;
	 	 }


	/*
	 * The trailerStyleClass for a div following a handle.
	 * Getter for trailerStyleClass
	 * @return trailerStyleClass value from local variable or value bindings
	 */
	 public String getTrailerStyleClass(  ){
	         if (null != this._trailerStyleClass)
        {
            return this._trailerStyleClass;
        	    }
        ValueBinding vb = getValueBinding("trailerStyleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.DataFilterSlider";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[27];
        values[0] = super.saveState(context);
 	 	          values[1] = _width;
	   	 	
  	 	          values[2] = _filterBy;
	   	 	
   	 	          values[3] = _startRange;
	   	 	
    	 	          values[4] = _endRange;
	   	 	
   	        values[5] = new Boolean(_storeResults);
	   	   values[6] = Boolean.valueOf(_storeResultsSet);	
	   	 	
  	 	          values[7] = _styleClass;
	   	 	
  	 	          values[8] = _style;
	   	 	
  	        values[9] = new Boolean(_onSlide);
	   	   values[10] = Boolean.valueOf(_onSlideSet);	
	   	 	
  	 	          values[11] = _handleValue;
	   	 	
  	 	          values[12] = saveAttachedState(context, _sliderListener );		
	   	 	
  	 	          values[13] = _trackStyleClass;
	   	 	
  	 	          values[14] = _handleStyleClass;
	   	 	
  	 	          values[15] = _for;
	   	 	
   	 	          values[16] = _increment;
	   	 	
  	 	          values[17] = _rangeStyleClass;
	   	 	
  	 	          values[18] = _fieldStyleClass;
	   	 	
  	        values[19] = new Boolean(_trailer);
	   	   values[20] = Boolean.valueOf(_trailerSet);	
	   	 	
  	        values[21] = new Boolean(_manualInput);
	   	   values[22] = Boolean.valueOf(_manualInputSet);	
	   	 	
   	 	          values[23] = _forValRef;
	   	 	
  	        values[24] = new Boolean(_onChange);
	   	   values[25] = Boolean.valueOf(_onChangeSet);	
	   	 	
  	 	          values[26] = _trailerStyleClass;
	   	 	
  	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
 	 	          _width = (String)values[1] ;
	   	 	
  	 	          _filterBy = (String)values[2] ;
	   	 	
   	 	          _startRange = (Integer)values[3] ;
	   	 	
    	 	          _endRange = (Integer)values[4] ;
	   	 	
   	        _storeResults = ((Boolean)values[5]).booleanValue();
	   	   _storeResultsSet = ((Boolean)values[6]).booleanValue();	
	   	 	
  	 	          _styleClass = (String)values[7] ;
	   	 	
  	 	          _style = (String)values[8] ;
	   	 	
  	        _onSlide = ((Boolean)values[9]).booleanValue();
	   	   _onSlideSet = ((Boolean)values[10]).booleanValue();	
	   	 	
  	 	          _handleValue = (Integer)values[11] ;
	   	 	
  	 	          _sliderListener = (MethodBinding)restoreAttachedState(context,values[12] );		
	   	 	
  	 	          _trackStyleClass = (String)values[13] ;
	   	 	
  	 	          _handleStyleClass = (String)values[14] ;
	   	 	
  	 	          _for = (String)values[15] ;
	   	 	
   	 	          _increment = (Integer)values[16] ;
	   	 	
  	 	          _rangeStyleClass = (String)values[17] ;
	   	 	
  	 	          _fieldStyleClass = (String)values[18] ;
	   	 	
  	        _trailer = ((Boolean)values[19]).booleanValue();
	   	   _trailerSet = ((Boolean)values[20]).booleanValue();	
	   	 	
  	        _manualInput = ((Boolean)values[21]).booleanValue();
	   	   _manualInputSet = ((Boolean)values[22]).booleanValue();	
	   	 	
   	 	          _forValRef = (String)values[23] ;
	   	 	
  	        _onChange = ((Boolean)values[24]).booleanValue();
	   	   _onChangeSet = ((Boolean)values[25]).booleanValue();	
	   	 	
  	 	          _trailerStyleClass = (String)values[26] ;
	   	 	
  	
		
	}	
// Utilites

}