/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import java.lang.Object ;
import org.richfaces.component.UIDatascroller ;
import javax.faces.el.MethodBinding ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.Datascroller
 * Component-Family org.richfaces.Datascroller
  	 * Renderer-Type org.richfaces.DataScrollerRenderer
  	 * 
 */
 public class HtmlDatascroller extends org.richfaces.component.UIDatascroller {

  public static final String COMPONENT_TYPE = "org.richfaces.Datascroller";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlDatascroller (){
  	  	setRendererType("org.richfaces.DataScrollerRenderer");
  	  }

// Component properties fields
 	/**
	 * maxPages
	 * Maximum quantity of pages
	 */
	 	 private int  _maxPages = 10;		
	/**
	 * Flag indicated what maxPages is set.
	 */
	 private boolean _maxPagesSet = false;	
	 	  	/**
	 * selectedStyle
	 * 
	 */
	 	 private String  _selectedStyle = null; /* Default is null*/
	 	  	/**
	 * tableStyle
	 * 
	 */
	 	 private String  _tableStyle = null; /* Default is null*/
	 	   	/**
	 * bypassUpdates
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 */
	 	 private boolean  _bypassUpdates = false;		
	/**
	 * Flag indicated what bypassUpdates is set.
	 */
	 private boolean _bypassUpdatesSet = false;	
	 	  	/**
	 * renderCurrentAsText
	 * 
	 */
	 	 private boolean  _renderCurrentAsText = true;		
	/**
	 * Flag indicated what renderCurrentAsText is set.
	 */
	 private boolean _renderCurrentAsTextSet = false;	
	 	  	/**
	 * limitToList
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 */
	 	 private boolean  _limitToList = false;		
	/**
	 * Flag indicated what limitToList is set.
	 */
	 private boolean _limitToListSet = false;	
	 	   	/**
	 * style
	 * 
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * onmouseover
	 * HTML: a script expression; a pointer is moved onto
	 */
	 	 private String  _onmouseover = null; /* Default is null*/
	 	  	/**
	 * for
	 * 
	 */
	 	 private String  _for = null; /* Default is null*/
	 	  	/**
	 * onkeyup
	 * HTML: a script expression; a key is released
	 */
	 	 private String  _onkeyup = null; /* Default is null*/
	 	   	/**
	 * timeout
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 */
	 	 private int  _timeout = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what timeout is set.
	 */
	 private boolean _timeoutSet = false;	
	 	    	/**
	 * onmouseout
	 * HTML: a script expression; a pointer is moved away
	 */
	 	 private String  _onmouseout = null; /* Default is null*/
	 	     	/**
	 * onmouseup
	 * HTML: script expression; a pointer button is released
	 */
	 	 private String  _onmouseup = null; /* Default is null*/
	 	  	/**
	 * binding
	 * 
	 */
	 	 private String  _binding = null; /* Default is null*/
	 	  	/**
	 * onmousemove
	 * HTML: a script expression; a pointer is moved within
	 */
	 	 private String  _onmousemove = null; /* Default is null*/
	 	   	/**
	 * actionListener
	 * MethodBinding pointing at method accepting  an ActionEvent with return type void
	 */
	 	 private MethodBinding  _actionListener = null; /* Default is null*/
	 	  	/**
	 * renderIfSinglePage
	 * If renderIfSinglePage=true then display datascroller if the data hold on one page
	 */
	 	 private boolean  _renderIfSinglePage = true;		
	/**
	 * Flag indicated what renderIfSinglePage is set.
	 */
	 private boolean _renderIfSinglePageSet = false;	
	 	  	/**
	 * oncomplete
	 * JavaScript code for call after request completed on client side
	 */
	 	 private String  _oncomplete = null; /* Default is null*/
	 	  	/**
	 * fastStep
	 * 
	 */
	 	 private int  _fastStep = 0;		
	/**
	 * Flag indicated what fastStep is set.
	 */
	 private boolean _fastStepSet = false;	
	 	    	/**
	 * reRender
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 */
	 	 private Object  _reRender = null; /* Default is null*/
	 	   	/**
	 * tableStyleClass
	 * 
	 */
	 	 private String  _tableStyleClass = null; /* Default is null*/
	 	  	/**
	 * styleClass
	 * 
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * onkeypress
	 * HTML: a script expression; a key is pressed and released
	 */
	 	 private String  _onkeypress = null; /* Default is null*/
	 	  	/**
	 * ajaxSingle
	 * 
	 */
	 	 private boolean  _ajaxSingle = true;		
	/**
	 * Flag indicated what ajaxSingle is set.
	 */
	 private boolean _ajaxSingleSet = false;	
	 	  	/**
	 * ondblclick
	 * HTML: a script expression; a pointer button is double-clicked
	 */
	 	 private String  _ondblclick = null; /* Default is null*/
	 	  	/**
	 * handleValue
	 * handleValue
	 */
	 	 private String  _handleValue = null; /* Default is null*/
	 	  	/**
	 * selectedStyleClass
	 * 
	 */
	 	 private String  _selectedStyleClass = null; /* Default is null*/
	 	  	/**
	 * value
	 * The current value for this component
	 */
	 	 private Object  _value = null; /* Default is null*/
	 	  	/**
	 * action
	 * MethodBinding pointing at the application action to be invoked,
            if this UIComponent is activated by the user, during the Apply
            Request Values or Invoke Application phase of the request
            processing lifecycle, depending on the value of the immediate
            property
	 */
	 	 private MethodBinding  _action = null; /* Default is null*/
	 	   	/**
	 * onclick
	 * HTML: a script expression; a pointer button is clicked
	 */
	 	 private String  _onclick = null; /* Default is null*/
	 	  	/**
	 * status
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 */
	 	 private String  _status = null; /* Default is null*/
	 	  	/**
	 * onkeydown
	 * HTML: a script expression; a key is pressed down
	 */
	 	 private String  _onkeydown = null; /* Default is null*/
	 	  	/**
	 * scrollerListener
	 * scrollerListener
	 */
	 	 private MethodBinding  _scrollerListener = null; /* Default is null*/
	 	  	/**
	 * onmousedown
	 * HTML: script expression; a pointer button is pressed down
	 */
	 	 private String  _onmousedown = null; /* Default is null*/
	 	  	/**
	 * requestDelay
	 * Delay ( in ms. ) for send ajax request on JavaScript
				event. In conjunction with events queue can reduce
				number of requests on keyboard or mouse move events.
	 */
	 	 private int  _requestDelay = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what requestDelay is set.
	 */
	 private boolean _requestDelaySet = false;	
	 	  	/**
	 * eventsQueue
	 * 
	 */
	 	 private String  _eventsQueue = null; /* Default is null*/
	 	  	/**
	 * immediate
	 * 
	 */
	 	 private boolean  _immediate = false;		
	/**
	 * Flag indicated what immediate is set.
	 */
	 private boolean _immediateSet = false;	
	 	  	/**
	 * data
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 */
	 	 private Object  _data = null; /* Default is null*/
	 	    	/**
	 * ignoreDupResponses
	 * 
	 */
	 	 private boolean  _ignoreDupResponses = true;		
	/**
	 * Flag indicated what ignoreDupResponses is set.
	 */
	 private boolean _ignoreDupResponsesSet = false;	
	 	 
// Getters-setters
 	/*
	 * Maximum quantity of pages
	 * Setter for maxPages
	 * @param maxPages - new value
	 */
	 public void setMaxPages( int  __maxPages ){
		this._maxPages = __maxPages;
	 		this._maxPagesSet = true;
	 	 }


	/*
	 * Maximum quantity of pages
	 * Getter for maxPages
	 * @return maxPages value from local variable or value bindings
	 */
	 public int getMaxPages(  ){
	 		 if(this._maxPagesSet){
			return this._maxPages;
		 }
    	ValueBinding vb = getValueBinding("maxPages");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._maxPages;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._maxPages);
    	}
	 	 }
	   	/*
	 * 
	 * Setter for selectedStyle
	 * @param selectedStyle - new value
	 */
	 public void setSelectedStyle( String  __selectedStyle ){
		this._selectedStyle = __selectedStyle;
	 	 }


	/*
	 * 
	 * Getter for selectedStyle
	 * @return selectedStyle value from local variable or value bindings
	 */
	 public String getSelectedStyle(  ){
	         if (null != this._selectedStyle)
        {
            return this._selectedStyle;
        	    }
        ValueBinding vb = getValueBinding("selectedStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for tableStyle
	 * @param tableStyle - new value
	 */
	 public void setTableStyle( String  __tableStyle ){
		this._tableStyle = __tableStyle;
	 	 }


	/*
	 * 
	 * Getter for tableStyle
	 * @return tableStyle value from local variable or value bindings
	 */
	 public String getTableStyle(  ){
	         if (null != this._tableStyle)
        {
            return this._tableStyle;
        	    }
        ValueBinding vb = getValueBinding("tableStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 * Setter for bypassUpdates
	 * @param bypassUpdates - new value
	 */
	 public void setBypassUpdates( boolean  __bypassUpdates ){
		this._bypassUpdates = __bypassUpdates;
	 		this._bypassUpdatesSet = true;
	 	 }


	/*
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 * Getter for bypassUpdates
	 * @return bypassUpdates value from local variable or value bindings
	 */
	 public boolean isBypassUpdates(  ){
	 		 if(this._bypassUpdatesSet){
			return this._bypassUpdates;
		 }
    	ValueBinding vb = getValueBinding("bypassUpdates");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._bypassUpdates;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._bypassUpdates);
    	}
	 	 }
	   	/*
	 * 
	 * Setter for renderCurrentAsText
	 * @param renderCurrentAsText - new value
	 */
	 public void setRenderCurrentAsText( boolean  __renderCurrentAsText ){
		this._renderCurrentAsText = __renderCurrentAsText;
	 		this._renderCurrentAsTextSet = true;
	 	 }


	/*
	 * 
	 * Getter for renderCurrentAsText
	 * @return renderCurrentAsText value from local variable or value bindings
	 */
	 public boolean isRenderCurrentAsText(  ){
	 		 if(this._renderCurrentAsTextSet){
			return this._renderCurrentAsText;
		 }
    	ValueBinding vb = getValueBinding("renderCurrentAsText");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._renderCurrentAsText;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._renderCurrentAsText);
    	}
	 	 }
	   	/*
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 * Setter for limitToList
	 * @param limitToList - new value
	 */
	 public void setLimitToList( boolean  __limitToList ){
		this._limitToList = __limitToList;
	 		this._limitToListSet = true;
	 	 }


	/*
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 * Getter for limitToList
	 * @return limitToList value from local variable or value bindings
	 */
	 public boolean isLimitToList(  ){
	 		 if(this._limitToListSet){
			return this._limitToList;
		 }
    	ValueBinding vb = getValueBinding("limitToList");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._limitToList;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._limitToList);
    	}
	 	 }
	    	/*
	 * 
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * 
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Setter for onmouseover
	 * @param onmouseover - new value
	 */
	 public void setOnmouseover( String  __onmouseover ){
		this._onmouseover = __onmouseover;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Getter for onmouseover
	 * @return onmouseover value from local variable or value bindings
	 */
	 public String getOnmouseover(  ){
	         if (null != this._onmouseover)
        {
            return this._onmouseover;
        	    }
        ValueBinding vb = getValueBinding("onmouseover");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for for
	 * @param for - new value
	 */
	 public void setFor( String  __for ){
		this._for = __for;
	 	 }


	/*
	 * 
	 * Getter for for
	 * @return for value from local variable or value bindings
	 */
	 public String getFor(  ){
	         if (null != this._for)
        {
            return this._for;
        	    }
        ValueBinding vb = getValueBinding("for");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is released
	 * Setter for onkeyup
	 * @param onkeyup - new value
	 */
	 public void setOnkeyup( String  __onkeyup ){
		this._onkeyup = __onkeyup;
	 	 }


	/*
	 * HTML: a script expression; a key is released
	 * Getter for onkeyup
	 * @return onkeyup value from local variable or value bindings
	 */
	 public String getOnkeyup(  ){
	         if (null != this._onkeyup)
        {
            return this._onkeyup;
        	    }
        ValueBinding vb = getValueBinding("onkeyup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Setter for timeout
	 * @param timeout - new value
	 */
	 public void setTimeout( int  __timeout ){
		this._timeout = __timeout;
	 		this._timeoutSet = true;
	 	 }


	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Getter for timeout
	 * @return timeout value from local variable or value bindings
	 */
	 public int getTimeout(  ){
	 		 if(this._timeoutSet){
			return this._timeout;
		 }
    	ValueBinding vb = getValueBinding("timeout");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._timeout;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._timeout);
    	}
	 	 }
	     	/*
	 * HTML: a script expression; a pointer is moved away
	 * Setter for onmouseout
	 * @param onmouseout - new value
	 */
	 public void setOnmouseout( String  __onmouseout ){
		this._onmouseout = __onmouseout;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved away
	 * Getter for onmouseout
	 * @return onmouseout value from local variable or value bindings
	 */
	 public String getOnmouseout(  ){
	         if (null != this._onmouseout)
        {
            return this._onmouseout;
        	    }
        ValueBinding vb = getValueBinding("onmouseout");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	      	/*
	 * HTML: script expression; a pointer button is released
	 * Setter for onmouseup
	 * @param onmouseup - new value
	 */
	 public void setOnmouseup( String  __onmouseup ){
		this._onmouseup = __onmouseup;
	 	 }


	/*
	 * HTML: script expression; a pointer button is released
	 * Getter for onmouseup
	 * @return onmouseup value from local variable or value bindings
	 */
	 public String getOnmouseup(  ){
	         if (null != this._onmouseup)
        {
            return this._onmouseup;
        	    }
        ValueBinding vb = getValueBinding("onmouseup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for binding
	 * @param binding - new value
	 */
	 public void setBinding( String  __binding ){
		this._binding = __binding;
	 	 }


	/*
	 * 
	 * Getter for binding
	 * @return binding value from local variable or value bindings
	 */
	 public String getBinding(  ){
	         if (null != this._binding)
        {
            return this._binding;
        	    }
        ValueBinding vb = getValueBinding("binding");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved within
	 * Setter for onmousemove
	 * @param onmousemove - new value
	 */
	 public void setOnmousemove( String  __onmousemove ){
		this._onmousemove = __onmousemove;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved within
	 * Getter for onmousemove
	 * @return onmousemove value from local variable or value bindings
	 */
	 public String getOnmousemove(  ){
	         if (null != this._onmousemove)
        {
            return this._onmousemove;
        	    }
        ValueBinding vb = getValueBinding("onmousemove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * MethodBinding pointing at method accepting  an ActionEvent with return type void
	 * Setter for actionListener
	 * @param actionListener - new value
	 */
	 public void setActionListener( MethodBinding  __actionListener ){
		this._actionListener = __actionListener;
	 	 }


	/*
	 * MethodBinding pointing at method accepting  an ActionEvent with return type void
	 * Getter for actionListener
	 * @return actionListener value from local variable or value bindings
	 */
	 public MethodBinding getActionListener(  ){
	         if (null != this._actionListener)
        {
            return this._actionListener;
                } else {
            return null;
        }
	 	 }
	   	/*
	 * If renderIfSinglePage=true then display datascroller if the data hold on one page
	 * Setter for renderIfSinglePage
	 * @param renderIfSinglePage - new value
	 */
	 public void setRenderIfSinglePage( boolean  __renderIfSinglePage ){
		this._renderIfSinglePage = __renderIfSinglePage;
	 		this._renderIfSinglePageSet = true;
	 	 }


	/*
	 * If renderIfSinglePage=true then display datascroller if the data hold on one page
	 * Getter for renderIfSinglePage
	 * @return renderIfSinglePage value from local variable or value bindings
	 */
	 public boolean isRenderIfSinglePage(  ){
	 		 if(this._renderIfSinglePageSet){
			return this._renderIfSinglePage;
		 }
    	ValueBinding vb = getValueBinding("renderIfSinglePage");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._renderIfSinglePage;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._renderIfSinglePage);
    	}
	 	 }
	   	/*
	 * JavaScript code for call after request completed on client side
	 * Setter for oncomplete
	 * @param oncomplete - new value
	 */
	 public void setOncomplete( String  __oncomplete ){
		this._oncomplete = __oncomplete;
	 	 }


	/*
	 * JavaScript code for call after request completed on client side
	 * Getter for oncomplete
	 * @return oncomplete value from local variable or value bindings
	 */
	 public String getOncomplete(  ){
	         if (null != this._oncomplete)
        {
            return this._oncomplete;
        	    }
        ValueBinding vb = getValueBinding("oncomplete");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for fastStep
	 * @param fastStep - new value
	 */
	 public void setFastStep( int  __fastStep ){
		this._fastStep = __fastStep;
	 		this._fastStepSet = true;
	 	 }


	/*
	 * 
	 * Getter for fastStep
	 * @return fastStep value from local variable or value bindings
	 */
	 public int getFastStep(  ){
	 		 if(this._fastStepSet){
			return this._fastStep;
		 }
    	ValueBinding vb = getValueBinding("fastStep");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._fastStep;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._fastStep);
    	}
	 	 }
	     	/*
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 * Setter for reRender
	 * @param reRender - new value
	 */
	 public void setReRender( Object  __reRender ){
		this._reRender = __reRender;
	 	 }


	/*
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 * Getter for reRender
	 * @return reRender value from local variable or value bindings
	 */
	 public Object getReRender(  ){
	         if (null != this._reRender)
        {
            return this._reRender;
        	    }
        ValueBinding vb = getValueBinding("reRender");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * 
	 * Setter for tableStyleClass
	 * @param tableStyleClass - new value
	 */
	 public void setTableStyleClass( String  __tableStyleClass ){
		this._tableStyleClass = __tableStyleClass;
	 	 }


	/*
	 * 
	 * Getter for tableStyleClass
	 * @return tableStyleClass value from local variable or value bindings
	 */
	 public String getTableStyleClass(  ){
	         if (null != this._tableStyleClass)
        {
            return this._tableStyleClass;
        	    }
        ValueBinding vb = getValueBinding("tableStyleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * 
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed and released
	 * Setter for onkeypress
	 * @param onkeypress - new value
	 */
	 public void setOnkeypress( String  __onkeypress ){
		this._onkeypress = __onkeypress;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed and released
	 * Getter for onkeypress
	 * @return onkeypress value from local variable or value bindings
	 */
	 public String getOnkeypress(  ){
	         if (null != this._onkeypress)
        {
            return this._onkeypress;
        	    }
        ValueBinding vb = getValueBinding("onkeypress");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for ajaxSingle
	 * @param ajaxSingle - new value
	 */
	 public void setAjaxSingle( boolean  __ajaxSingle ){
		this._ajaxSingle = __ajaxSingle;
	 		this._ajaxSingleSet = true;
	 	 }


	/*
	 * 
	 * Getter for ajaxSingle
	 * @return ajaxSingle value from local variable or value bindings
	 */
	 public boolean isAjaxSingle(  ){
	 		 if(this._ajaxSingleSet){
			return this._ajaxSingle;
		 }
    	ValueBinding vb = getValueBinding("ajaxSingle");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ajaxSingle;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ajaxSingle);
    	}
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Setter for ondblclick
	 * @param ondblclick - new value
	 */
	 public void setOndblclick( String  __ondblclick ){
		this._ondblclick = __ondblclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Getter for ondblclick
	 * @return ondblclick value from local variable or value bindings
	 */
	 public String getOndblclick(  ){
	         if (null != this._ondblclick)
        {
            return this._ondblclick;
        	    }
        ValueBinding vb = getValueBinding("ondblclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * handleValue
	 * Setter for handleValue
	 * @param handleValue - new value
	 */
	 public void setHandleValue( String  __handleValue ){
		this._handleValue = __handleValue;
	 	 }


	/*
	 * handleValue
	 * Getter for handleValue
	 * @return handleValue value from local variable or value bindings
	 */
	 public String getHandleValue(  ){
	         if (null != this._handleValue)
        {
            return this._handleValue;
        	    }
        ValueBinding vb = getValueBinding("handleValue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for selectedStyleClass
	 * @param selectedStyleClass - new value
	 */
	 public void setSelectedStyleClass( String  __selectedStyleClass ){
		this._selectedStyleClass = __selectedStyleClass;
	 	 }


	/*
	 * 
	 * Getter for selectedStyleClass
	 * @return selectedStyleClass value from local variable or value bindings
	 */
	 public String getSelectedStyleClass(  ){
	         if (null != this._selectedStyleClass)
        {
            return this._selectedStyleClass;
        	    }
        ValueBinding vb = getValueBinding("selectedStyleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The current value for this component
	 * Setter for value
	 * @param value - new value
	 */
	 public void setValue( Object  __value ){
		this._value = __value;
	 	 }


	/*
	 * The current value for this component
	 * Getter for value
	 * @return value value from local variable or value bindings
	 */
	 public Object getValue(  ){
	         if (null != this._value)
        {
            return this._value;
        	    }
        ValueBinding vb = getValueBinding("value");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * MethodBinding pointing at the application action to be invoked,
            if this UIComponent is activated by the user, during the Apply
            Request Values or Invoke Application phase of the request
            processing lifecycle, depending on the value of the immediate
            property
	 * Setter for action
	 * @param action - new value
	 */
	 public void setAction( MethodBinding  __action ){
		this._action = __action;
	 	 }


	/*
	 * MethodBinding pointing at the application action to be invoked,
            if this UIComponent is activated by the user, during the Apply
            Request Values or Invoke Application phase of the request
            processing lifecycle, depending on the value of the immediate
            property
	 * Getter for action
	 * @return action value from local variable or value bindings
	 */
	 public MethodBinding getAction(  ){
	         if (null != this._action)
        {
            return this._action;
                } else {
            return null;
        }
	 	 }
	    	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Setter for onclick
	 * @param onclick - new value
	 */
	 public void setOnclick( String  __onclick ){
		this._onclick = __onclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Getter for onclick
	 * @return onclick value from local variable or value bindings
	 */
	 public String getOnclick(  ){
	         if (null != this._onclick)
        {
            return this._onclick;
        	    }
        ValueBinding vb = getValueBinding("onclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 * Setter for status
	 * @param status - new value
	 */
	 public void setStatus( String  __status ){
		this._status = __status;
	 	 }


	/*
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 * Getter for status
	 * @return status value from local variable or value bindings
	 */
	 public String getStatus(  ){
	         if (null != this._status)
        {
            return this._status;
        	    }
        ValueBinding vb = getValueBinding("status");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed down
	 * Setter for onkeydown
	 * @param onkeydown - new value
	 */
	 public void setOnkeydown( String  __onkeydown ){
		this._onkeydown = __onkeydown;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed down
	 * Getter for onkeydown
	 * @return onkeydown value from local variable or value bindings
	 */
	 public String getOnkeydown(  ){
	         if (null != this._onkeydown)
        {
            return this._onkeydown;
        	    }
        ValueBinding vb = getValueBinding("onkeydown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * scrollerListener
	 * Setter for scrollerListener
	 * @param scrollerListener - new value
	 */
	 public void setScrollerListener( MethodBinding  __scrollerListener ){
		this._scrollerListener = __scrollerListener;
	 	 }


	/*
	 * scrollerListener
	 * Getter for scrollerListener
	 * @return scrollerListener value from local variable or value bindings
	 */
	 public MethodBinding getScrollerListener(  ){
	         if (null != this._scrollerListener)
        {
            return this._scrollerListener;
                } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Setter for onmousedown
	 * @param onmousedown - new value
	 */
	 public void setOnmousedown( String  __onmousedown ){
		this._onmousedown = __onmousedown;
	 	 }


	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Getter for onmousedown
	 * @return onmousedown value from local variable or value bindings
	 */
	 public String getOnmousedown(  ){
	         if (null != this._onmousedown)
        {
            return this._onmousedown;
        	    }
        ValueBinding vb = getValueBinding("onmousedown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Delay ( in ms. ) for send ajax request on JavaScript
				event. In conjunction with events queue can reduce
				number of requests on keyboard or mouse move events.
	 * Setter for requestDelay
	 * @param requestDelay - new value
	 */
	 public void setRequestDelay( int  __requestDelay ){
		this._requestDelay = __requestDelay;
	 		this._requestDelaySet = true;
	 	 }


	/*
	 * Delay ( in ms. ) for send ajax request on JavaScript
				event. In conjunction with events queue can reduce
				number of requests on keyboard or mouse move events.
	 * Getter for requestDelay
	 * @return requestDelay value from local variable or value bindings
	 */
	 public int getRequestDelay(  ){
	 		 if(this._requestDelaySet){
			return this._requestDelay;
		 }
    	ValueBinding vb = getValueBinding("requestDelay");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._requestDelay;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._requestDelay);
    	}
	 	 }
	   	/*
	 * 
	 * Setter for eventsQueue
	 * @param eventsQueue - new value
	 */
	 public void setEventsQueue( String  __eventsQueue ){
		this._eventsQueue = __eventsQueue;
	 	 }


	/*
	 * 
	 * Getter for eventsQueue
	 * @return eventsQueue value from local variable or value bindings
	 */
	 public String getEventsQueue(  ){
	         if (null != this._eventsQueue)
        {
            return this._eventsQueue;
        	    }
        ValueBinding vb = getValueBinding("eventsQueue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for immediate
	 * @param immediate - new value
	 */
	 public void setImmediate( boolean  __immediate ){
		this._immediate = __immediate;
	 		this._immediateSet = true;
	 	 }


	/*
	 * 
	 * Getter for immediate
	 * @return immediate value from local variable or value bindings
	 */
	 public boolean isImmediate(  ){
	 		 if(this._immediateSet){
			return this._immediate;
		 }
    	ValueBinding vb = getValueBinding("immediate");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._immediate;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._immediate);
    	}
	 	 }
	   	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Setter for data
	 * @param data - new value
	 */
	 public void setData( Object  __data ){
		this._data = __data;
	 	 }


	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Getter for data
	 * @return data value from local variable or value bindings
	 */
	 public Object getData(  ){
	         if (null != this._data)
        {
            return this._data;
        	    }
        ValueBinding vb = getValueBinding("data");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * 
	 * Setter for ignoreDupResponses
	 * @param ignoreDupResponses - new value
	 */
	 public void setIgnoreDupResponses( boolean  __ignoreDupResponses ){
		this._ignoreDupResponses = __ignoreDupResponses;
	 		this._ignoreDupResponsesSet = true;
	 	 }


	/*
	 * 
	 * Getter for ignoreDupResponses
	 * @return ignoreDupResponses value from local variable or value bindings
	 */
	 public boolean isIgnoreDupResponses(  ){
	 		 if(this._ignoreDupResponsesSet){
			return this._ignoreDupResponses;
		 }
    	ValueBinding vb = getValueBinding("ignoreDupResponses");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ignoreDupResponses;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ignoreDupResponses);
    	}
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.Datascroller";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[51];
        values[0] = super.saveState(context);
 	        values[1] = new Integer(_maxPages);
	   	   values[2] = Boolean.valueOf(_maxPagesSet);	
	   	 	
  	 	          values[3] = _selectedStyle;
	   	 	
  	 	          values[4] = _tableStyle;
	   	 	
   	        values[5] = new Boolean(_bypassUpdates);
	   	   values[6] = Boolean.valueOf(_bypassUpdatesSet);	
	   	 	
  	        values[7] = new Boolean(_renderCurrentAsText);
	   	   values[8] = Boolean.valueOf(_renderCurrentAsTextSet);	
	   	 	
  	        values[9] = new Boolean(_limitToList);
	   	   values[10] = Boolean.valueOf(_limitToListSet);	
	   	 	
   	 	          values[11] = _style;
	   	 	
  	 	          values[12] = _onmouseover;
	   	 	
  	 	          values[13] = _for;
	   	 	
  	 	          values[14] = _onkeyup;
	   	 	
   	        values[15] = new Integer(_timeout);
	   	   values[16] = Boolean.valueOf(_timeoutSet);	
	   	 	
    	 	          values[17] = _onmouseout;
	   	 	
     	 	          values[18] = _onmouseup;
	   	 	
  	 	          values[19] = _binding;
	   	 	
  	 	          values[20] = _onmousemove;
	   	 	
   	 	          values[21] = saveAttachedState(context, _actionListener );		
	   	 	
  	        values[22] = new Boolean(_renderIfSinglePage);
	   	   values[23] = Boolean.valueOf(_renderIfSinglePageSet);	
	   	 	
  	 	          values[24] = _oncomplete;
	   	 	
  	        values[25] = new Integer(_fastStep);
	   	   values[26] = Boolean.valueOf(_fastStepSet);	
	   	 	
    	 	          values[27] = _reRender;
	   	 	
   	 	          values[28] = _tableStyleClass;
	   	 	
  	 	          values[29] = _styleClass;
	   	 	
  	 	          values[30] = _onkeypress;
	   	 	
  	        values[31] = new Boolean(_ajaxSingle);
	   	   values[32] = Boolean.valueOf(_ajaxSingleSet);	
	   	 	
  	 	          values[33] = _ondblclick;
	   	 	
  	 	          values[34] = _handleValue;
	   	 	
  	 	          values[35] = _selectedStyleClass;
	   	 	
  	 	          values[36] = _value;
	   	 	
  	 	          values[37] = saveAttachedState(context, _action );		
	   	 	
   	 	          values[38] = _onclick;
	   	 	
  	 	          values[39] = _status;
	   	 	
  	 	          values[40] = _onkeydown;
	   	 	
  	 	          values[41] = saveAttachedState(context, _scrollerListener );		
	   	 	
  	 	          values[42] = _onmousedown;
	   	 	
  	        values[43] = new Integer(_requestDelay);
	   	   values[44] = Boolean.valueOf(_requestDelaySet);	
	   	 	
  	 	          values[45] = _eventsQueue;
	   	 	
  	        values[46] = new Boolean(_immediate);
	   	   values[47] = Boolean.valueOf(_immediateSet);	
	   	 	
  	 	          values[48] = _data;
	   	 	
    	        values[49] = new Boolean(_ignoreDupResponses);
	   	   values[50] = Boolean.valueOf(_ignoreDupResponsesSet);	
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
 	        _maxPages = ((Integer)values[1]).intValue();
	   	   _maxPagesSet = ((Boolean)values[2]).booleanValue();	
	   	 	
  	 	          _selectedStyle = (String)values[3] ;
	   	 	
  	 	          _tableStyle = (String)values[4] ;
	   	 	
   	        _bypassUpdates = ((Boolean)values[5]).booleanValue();
	   	   _bypassUpdatesSet = ((Boolean)values[6]).booleanValue();	
	   	 	
  	        _renderCurrentAsText = ((Boolean)values[7]).booleanValue();
	   	   _renderCurrentAsTextSet = ((Boolean)values[8]).booleanValue();	
	   	 	
  	        _limitToList = ((Boolean)values[9]).booleanValue();
	   	   _limitToListSet = ((Boolean)values[10]).booleanValue();	
	   	 	
   	 	          _style = (String)values[11] ;
	   	 	
  	 	          _onmouseover = (String)values[12] ;
	   	 	
  	 	          _for = (String)values[13] ;
	   	 	
  	 	          _onkeyup = (String)values[14] ;
	   	 	
   	        _timeout = ((Integer)values[15]).intValue();
	   	   _timeoutSet = ((Boolean)values[16]).booleanValue();	
	   	 	
    	 	          _onmouseout = (String)values[17] ;
	   	 	
     	 	          _onmouseup = (String)values[18] ;
	   	 	
  	 	          _binding = (String)values[19] ;
	   	 	
  	 	          _onmousemove = (String)values[20] ;
	   	 	
   	 	          _actionListener = (MethodBinding)restoreAttachedState(context,values[21] );		
	   	 	
  	        _renderIfSinglePage = ((Boolean)values[22]).booleanValue();
	   	   _renderIfSinglePageSet = ((Boolean)values[23]).booleanValue();	
	   	 	
  	 	          _oncomplete = (String)values[24] ;
	   	 	
  	        _fastStep = ((Integer)values[25]).intValue();
	   	   _fastStepSet = ((Boolean)values[26]).booleanValue();	
	   	 	
    	 	          _reRender = (Object)values[27] ;
	   	 	
   	 	          _tableStyleClass = (String)values[28] ;
	   	 	
  	 	          _styleClass = (String)values[29] ;
	   	 	
  	 	          _onkeypress = (String)values[30] ;
	   	 	
  	        _ajaxSingle = ((Boolean)values[31]).booleanValue();
	   	   _ajaxSingleSet = ((Boolean)values[32]).booleanValue();	
	   	 	
  	 	          _ondblclick = (String)values[33] ;
	   	 	
  	 	          _handleValue = (String)values[34] ;
	   	 	
  	 	          _selectedStyleClass = (String)values[35] ;
	   	 	
  	 	          _value = (Object)values[36] ;
	   	 	
  	 	          _action = (MethodBinding)restoreAttachedState(context,values[37] );		
	   	 	
   	 	          _onclick = (String)values[38] ;
	   	 	
  	 	          _status = (String)values[39] ;
	   	 	
  	 	          _onkeydown = (String)values[40] ;
	   	 	
  	 	          _scrollerListener = (MethodBinding)restoreAttachedState(context,values[41] );		
	   	 	
  	 	          _onmousedown = (String)values[42] ;
	   	 	
  	        _requestDelay = ((Integer)values[43]).intValue();
	   	   _requestDelaySet = ((Boolean)values[44]).booleanValue();	
	   	 	
  	 	          _eventsQueue = (String)values[45] ;
	   	 	
  	        _immediate = ((Boolean)values[46]).booleanValue();
	   	   _immediateSet = ((Boolean)values[47]).booleanValue();	
	   	 	
  	 	          _data = (Object)values[48] ;
	   	 	
    	        _ignoreDupResponses = ((Boolean)values[49]).booleanValue();
	   	   _ignoreDupResponsesSet = ((Boolean)values[50]).booleanValue();	
	   	 	
 	
		
	}	
// Utilites

}