/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import org.richfaces.component.UIGmap ;
import java.lang.String ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.Gmap
 * Component-Family org.richfaces.Gmap
  	 * Renderer-Type org.richfaces.GmapRenderer
  	 * It presents the google map in JSF applications
 */
 public class HtmlGmap extends org.richfaces.component.UIGmap {

  public static final String COMPONENT_TYPE = "org.richfaces.Gmap";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlGmap (){
  	  	setRendererType("org.richfaces.GmapRenderer");
  	  }

// Component properties fields
 	/**
	 * lat
	 * Initial latitude coordinate in degrees, as a number between -90 and +90
	 */
	 	 private String  _lat = null; /* Default is "37.9721046"*/
	 	  	/**
	 * zoom
	 * Initial zoom level as a number between 1 and 18. The default value is 17
	 */
	 	 private String  _zoom = null; /* Default is "17"*/
	 	  	/**
	 * gmapKey
	 * Google Map key. A single Maps API key is valid for a single "directory" on your web server
	 */
	 	 private String  _gmapKey = null; /* Default is "internal"*/
	 	  	/**
	 * showGLargeMapControl
	 * Shows the GLarge control. The default value is "true"
	 */
	 	 private String  _showGLargeMapControl = null; /* Default is "true"*/
	 	    	/**
	 * showGScaleControl
	 * It shows the scale control. The default value is "true"
	 */
	 	 private String  _showGScaleControl = null; /* Default is "true"*/
	 	  	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * onkeypress
	 * HTML: a script expression; a key is pressed and released
	 */
	 	 private String  _onkeypress = null; /* Default is null*/
	 	  	/**
	 * ondblclick
	 * HTML: a script expression; a pointer button is double-clicked
	 */
	 	 private String  _ondblclick = null; /* Default is null*/
	 	  	/**
	 * enableDoubleClickZoom
	 * Enables zooming in by a double click. The default value is "false"
	 */
	 	 private String  _enableDoubleClickZoom = null; /* Default is "false"*/
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * mapType
	 * Initial map type. The possible values are  G_NORMAL_MAP, G_SATELLITE_MAP,
                        G_HYBRID_MAP. The default value is G_SATELLITE_MAP
	 */
	 	 private String  _mapType = null; /* Default is "G_SATELLITE_MAP"*/
	 	  	/**
	 * onmouseover
	 * HTML: a script expression; a pointer is moved onto
	 */
	 	 private String  _onmouseover = null; /* Default is null*/
	 	  	/**
	 * enableInfoWindow
	 * Enables Info Window. The default value is "true"
	 */
	 	 private String  _enableInfoWindow = null; /* Default is "true"*/
	 	  	/**
	 * onkeyup
	 * HTML: a script expression; a key is released
	 */
	 	 private String  _onkeyup = null; /* Default is null*/
	 	  	/**
	 * enableContinuousZoom
	 * Enables continuous smooth zooming for selected browsers. The default value is "false"
	 */
	 	 private String  _enableContinuousZoom = null; /* Default is "false"*/
	 	  	/**
	 * warningMessage
	 * The warning message that appears if a browser is not compatible with Google Map.
			The default value is "Your browser does not support Google Maps"
	 */
	 	 private String  _warningMessage = null; /* Default is "Your browser does not support Google Maps"*/
	 	  	/**
	 * onclick
	 * HTML: a script expression; a pointer button is clicked
	 */
	 	 private String  _onclick = null; /* Default is null*/
	 	  	/**
	 * gmapVar
	 * The javascript variable that is used to access the Google Map API. If you have
			 more than one Google Map components on the same page, use individual
			 key for each of them. The default variable name is "map" (without quotes)
	 */
	 	 private String  _gmapVar = null; /* Default is "map"*/
	 	  	/**
	 * onmouseout
	 * HTML: a script expression; a pointer is moved away
	 */
	 	 private String  _onmouseout = null; /* Default is null*/
	 	  	/**
	 * onkeydown
	 * HTML: a script expression; a key is pressed down
	 */
	 	 private String  _onkeydown = null; /* Default is null*/
	 	  	/**
	 * onmousedown
	 * HTML: script expression; a pointer button is pressed down
	 */
	 	 private String  _onmousedown = null; /* Default is null*/
	 	  	/**
	 * enableDragging
	 * Enables a map dragging with the mouse. The default value is "true"
	 */
	 	 private String  _enableDragging = null; /* Default is "true"*/
	 	  	/**
	 * showGMapTypeControl
	 * Shows the Type switch control. The default value is "true"
	 */
	 	 private String  _showGMapTypeControl = null; /* Default is "true"*/
	 	  	/**
	 * onmouseup
	 * HTML: script expression; a pointer button is released
	 */
	 	 private String  _onmouseup = null; /* Default is null*/
	 	   	/**
	 * lng
	 * Initial longitude coordinate in degrees, as a number between -180 and +180
	 */
	 	 private String  _lng = null; /* Default is "-122.0424842834"*/
	 	  	/**
	 * onmousemove
	 * HTML: a script expression; a pointer is moved within
	 */
	 	 private String  _onmousemove = null; /* Default is null*/
	 	 
// Getters-setters
 	/*
	 * Initial latitude coordinate in degrees, as a number between -90 and +90
	 * Setter for lat
	 * @param lat - new value
	 */
	 public void setLat( String  __lat ){
		this._lat = __lat;
	 	 }


	/*
	 * Initial latitude coordinate in degrees, as a number between -90 and +90
	 * Getter for lat
	 * @return lat value from local variable or value bindings
	 */
	 public String getLat(  ){
	         if (null != this._lat)
        {
            return this._lat;
        	    }
        ValueBinding vb = getValueBinding("lat");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "37.9721046";
        }
	 	 }
	   	/*
	 * Initial zoom level as a number between 1 and 18. The default value is 17
	 * Setter for zoom
	 * @param zoom - new value
	 */
	 public void setZoom( String  __zoom ){
		this._zoom = __zoom;
	 	 }


	/*
	 * Initial zoom level as a number between 1 and 18. The default value is 17
	 * Getter for zoom
	 * @return zoom value from local variable or value bindings
	 */
	 public String getZoom(  ){
	         if (null != this._zoom)
        {
            return this._zoom;
        	    }
        ValueBinding vb = getValueBinding("zoom");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "17";
        }
	 	 }
	   	/*
	 * Google Map key. A single Maps API key is valid for a single "directory" on your web server
	 * Setter for gmapKey
	 * @param gmapKey - new value
	 */
	 public void setGmapKey( String  __gmapKey ){
		this._gmapKey = __gmapKey;
	 	 }


	/*
	 * Google Map key. A single Maps API key is valid for a single "directory" on your web server
	 * Getter for gmapKey
	 * @return gmapKey value from local variable or value bindings
	 */
	 public String getGmapKey(  ){
	         if (null != this._gmapKey)
        {
            return this._gmapKey;
        	    }
        ValueBinding vb = getValueBinding("gmapKey");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "internal";
        }
	 	 }
	   	/*
	 * Shows the GLarge control. The default value is "true"
	 * Setter for showGLargeMapControl
	 * @param showGLargeMapControl - new value
	 */
	 public void setShowGLargeMapControl( String  __showGLargeMapControl ){
		this._showGLargeMapControl = __showGLargeMapControl;
	 	 }


	/*
	 * Shows the GLarge control. The default value is "true"
	 * Getter for showGLargeMapControl
	 * @return showGLargeMapControl value from local variable or value bindings
	 */
	 public String getShowGLargeMapControl(  ){
	         if (null != this._showGLargeMapControl)
        {
            return this._showGLargeMapControl;
        	    }
        ValueBinding vb = getValueBinding("showGLargeMapControl");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "true";
        }
	 	 }
	     	/*
	 * It shows the scale control. The default value is "true"
	 * Setter for showGScaleControl
	 * @param showGScaleControl - new value
	 */
	 public void setShowGScaleControl( String  __showGScaleControl ){
		this._showGScaleControl = __showGScaleControl;
	 	 }


	/*
	 * It shows the scale control. The default value is "true"
	 * Getter for showGScaleControl
	 * @return showGScaleControl value from local variable or value bindings
	 */
	 public String getShowGScaleControl(  ){
	         if (null != this._showGScaleControl)
        {
            return this._showGScaleControl;
        	    }
        ValueBinding vb = getValueBinding("showGScaleControl");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "true";
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed and released
	 * Setter for onkeypress
	 * @param onkeypress - new value
	 */
	 public void setOnkeypress( String  __onkeypress ){
		this._onkeypress = __onkeypress;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed and released
	 * Getter for onkeypress
	 * @return onkeypress value from local variable or value bindings
	 */
	 public String getOnkeypress(  ){
	         if (null != this._onkeypress)
        {
            return this._onkeypress;
        	    }
        ValueBinding vb = getValueBinding("onkeypress");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Setter for ondblclick
	 * @param ondblclick - new value
	 */
	 public void setOndblclick( String  __ondblclick ){
		this._ondblclick = __ondblclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Getter for ondblclick
	 * @return ondblclick value from local variable or value bindings
	 */
	 public String getOndblclick(  ){
	         if (null != this._ondblclick)
        {
            return this._ondblclick;
        	    }
        ValueBinding vb = getValueBinding("ondblclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Enables zooming in by a double click. The default value is "false"
	 * Setter for enableDoubleClickZoom
	 * @param enableDoubleClickZoom - new value
	 */
	 public void setEnableDoubleClickZoom( String  __enableDoubleClickZoom ){
		this._enableDoubleClickZoom = __enableDoubleClickZoom;
	 	 }


	/*
	 * Enables zooming in by a double click. The default value is "false"
	 * Getter for enableDoubleClickZoom
	 * @return enableDoubleClickZoom value from local variable or value bindings
	 */
	 public String getEnableDoubleClickZoom(  ){
	         if (null != this._enableDoubleClickZoom)
        {
            return this._enableDoubleClickZoom;
        	    }
        ValueBinding vb = getValueBinding("enableDoubleClickZoom");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "false";
        }
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Initial map type. The possible values are  G_NORMAL_MAP, G_SATELLITE_MAP,
                        G_HYBRID_MAP. The default value is G_SATELLITE_MAP
	 * Setter for mapType
	 * @param mapType - new value
	 */
	 public void setMapType( String  __mapType ){
		this._mapType = __mapType;
	 	 }


	/*
	 * Initial map type. The possible values are  G_NORMAL_MAP, G_SATELLITE_MAP,
                        G_HYBRID_MAP. The default value is G_SATELLITE_MAP
	 * Getter for mapType
	 * @return mapType value from local variable or value bindings
	 */
	 public String getMapType(  ){
	         if (null != this._mapType)
        {
            return this._mapType;
        	    }
        ValueBinding vb = getValueBinding("mapType");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "G_SATELLITE_MAP";
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Setter for onmouseover
	 * @param onmouseover - new value
	 */
	 public void setOnmouseover( String  __onmouseover ){
		this._onmouseover = __onmouseover;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Getter for onmouseover
	 * @return onmouseover value from local variable or value bindings
	 */
	 public String getOnmouseover(  ){
	         if (null != this._onmouseover)
        {
            return this._onmouseover;
        	    }
        ValueBinding vb = getValueBinding("onmouseover");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Enables Info Window. The default value is "true"
	 * Setter for enableInfoWindow
	 * @param enableInfoWindow - new value
	 */
	 public void setEnableInfoWindow( String  __enableInfoWindow ){
		this._enableInfoWindow = __enableInfoWindow;
	 	 }


	/*
	 * Enables Info Window. The default value is "true"
	 * Getter for enableInfoWindow
	 * @return enableInfoWindow value from local variable or value bindings
	 */
	 public String getEnableInfoWindow(  ){
	         if (null != this._enableInfoWindow)
        {
            return this._enableInfoWindow;
        	    }
        ValueBinding vb = getValueBinding("enableInfoWindow");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "true";
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is released
	 * Setter for onkeyup
	 * @param onkeyup - new value
	 */
	 public void setOnkeyup( String  __onkeyup ){
		this._onkeyup = __onkeyup;
	 	 }


	/*
	 * HTML: a script expression; a key is released
	 * Getter for onkeyup
	 * @return onkeyup value from local variable or value bindings
	 */
	 public String getOnkeyup(  ){
	         if (null != this._onkeyup)
        {
            return this._onkeyup;
        	    }
        ValueBinding vb = getValueBinding("onkeyup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Enables continuous smooth zooming for selected browsers. The default value is "false"
	 * Setter for enableContinuousZoom
	 * @param enableContinuousZoom - new value
	 */
	 public void setEnableContinuousZoom( String  __enableContinuousZoom ){
		this._enableContinuousZoom = __enableContinuousZoom;
	 	 }


	/*
	 * Enables continuous smooth zooming for selected browsers. The default value is "false"
	 * Getter for enableContinuousZoom
	 * @return enableContinuousZoom value from local variable or value bindings
	 */
	 public String getEnableContinuousZoom(  ){
	         if (null != this._enableContinuousZoom)
        {
            return this._enableContinuousZoom;
        	    }
        ValueBinding vb = getValueBinding("enableContinuousZoom");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "false";
        }
	 	 }
	   	/*
	 * The warning message that appears if a browser is not compatible with Google Map.
			The default value is "Your browser does not support Google Maps"
	 * Setter for warningMessage
	 * @param warningMessage - new value
	 */
	 public void setWarningMessage( String  __warningMessage ){
		this._warningMessage = __warningMessage;
	 	 }


	/*
	 * The warning message that appears if a browser is not compatible with Google Map.
			The default value is "Your browser does not support Google Maps"
	 * Getter for warningMessage
	 * @return warningMessage value from local variable or value bindings
	 */
	 public String getWarningMessage(  ){
	         if (null != this._warningMessage)
        {
            return this._warningMessage;
        	    }
        ValueBinding vb = getValueBinding("warningMessage");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "Your browser does not support Google Maps";
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Setter for onclick
	 * @param onclick - new value
	 */
	 public void setOnclick( String  __onclick ){
		this._onclick = __onclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Getter for onclick
	 * @return onclick value from local variable or value bindings
	 */
	 public String getOnclick(  ){
	         if (null != this._onclick)
        {
            return this._onclick;
        	    }
        ValueBinding vb = getValueBinding("onclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The javascript variable that is used to access the Google Map API. If you have
			 more than one Google Map components on the same page, use individual
			 key for each of them. The default variable name is "map" (without quotes)
	 * Setter for gmapVar
	 * @param gmapVar - new value
	 */
	 public void setGmapVar( String  __gmapVar ){
		this._gmapVar = __gmapVar;
	 	 }


	/*
	 * The javascript variable that is used to access the Google Map API. If you have
			 more than one Google Map components on the same page, use individual
			 key for each of them. The default variable name is "map" (without quotes)
	 * Getter for gmapVar
	 * @return gmapVar value from local variable or value bindings
	 */
	 public String getGmapVar(  ){
	         if (null != this._gmapVar)
        {
            return this._gmapVar;
        	    }
        ValueBinding vb = getValueBinding("gmapVar");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "map";
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved away
	 * Setter for onmouseout
	 * @param onmouseout - new value
	 */
	 public void setOnmouseout( String  __onmouseout ){
		this._onmouseout = __onmouseout;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved away
	 * Getter for onmouseout
	 * @return onmouseout value from local variable or value bindings
	 */
	 public String getOnmouseout(  ){
	         if (null != this._onmouseout)
        {
            return this._onmouseout;
        	    }
        ValueBinding vb = getValueBinding("onmouseout");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed down
	 * Setter for onkeydown
	 * @param onkeydown - new value
	 */
	 public void setOnkeydown( String  __onkeydown ){
		this._onkeydown = __onkeydown;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed down
	 * Getter for onkeydown
	 * @return onkeydown value from local variable or value bindings
	 */
	 public String getOnkeydown(  ){
	         if (null != this._onkeydown)
        {
            return this._onkeydown;
        	    }
        ValueBinding vb = getValueBinding("onkeydown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Setter for onmousedown
	 * @param onmousedown - new value
	 */
	 public void setOnmousedown( String  __onmousedown ){
		this._onmousedown = __onmousedown;
	 	 }


	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Getter for onmousedown
	 * @return onmousedown value from local variable or value bindings
	 */
	 public String getOnmousedown(  ){
	         if (null != this._onmousedown)
        {
            return this._onmousedown;
        	    }
        ValueBinding vb = getValueBinding("onmousedown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Enables a map dragging with the mouse. The default value is "true"
	 * Setter for enableDragging
	 * @param enableDragging - new value
	 */
	 public void setEnableDragging( String  __enableDragging ){
		this._enableDragging = __enableDragging;
	 	 }


	/*
	 * Enables a map dragging with the mouse. The default value is "true"
	 * Getter for enableDragging
	 * @return enableDragging value from local variable or value bindings
	 */
	 public String getEnableDragging(  ){
	         if (null != this._enableDragging)
        {
            return this._enableDragging;
        	    }
        ValueBinding vb = getValueBinding("enableDragging");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "true";
        }
	 	 }
	   	/*
	 * Shows the Type switch control. The default value is "true"
	 * Setter for showGMapTypeControl
	 * @param showGMapTypeControl - new value
	 */
	 public void setShowGMapTypeControl( String  __showGMapTypeControl ){
		this._showGMapTypeControl = __showGMapTypeControl;
	 	 }


	/*
	 * Shows the Type switch control. The default value is "true"
	 * Getter for showGMapTypeControl
	 * @return showGMapTypeControl value from local variable or value bindings
	 */
	 public String getShowGMapTypeControl(  ){
	         if (null != this._showGMapTypeControl)
        {
            return this._showGMapTypeControl;
        	    }
        ValueBinding vb = getValueBinding("showGMapTypeControl");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "true";
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is released
	 * Setter for onmouseup
	 * @param onmouseup - new value
	 */
	 public void setOnmouseup( String  __onmouseup ){
		this._onmouseup = __onmouseup;
	 	 }


	/*
	 * HTML: script expression; a pointer button is released
	 * Getter for onmouseup
	 * @return onmouseup value from local variable or value bindings
	 */
	 public String getOnmouseup(  ){
	         if (null != this._onmouseup)
        {
            return this._onmouseup;
        	    }
        ValueBinding vb = getValueBinding("onmouseup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Initial longitude coordinate in degrees, as a number between -180 and +180
	 * Setter for lng
	 * @param lng - new value
	 */
	 public void setLng( String  __lng ){
		this._lng = __lng;
	 	 }


	/*
	 * Initial longitude coordinate in degrees, as a number between -180 and +180
	 * Getter for lng
	 * @return lng value from local variable or value bindings
	 */
	 public String getLng(  ){
	         if (null != this._lng)
        {
            return this._lng;
        	    }
        ValueBinding vb = getValueBinding("lng");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "-122.0424842834";
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved within
	 * Setter for onmousemove
	 * @param onmousemove - new value
	 */
	 public void setOnmousemove( String  __onmousemove ){
		this._onmousemove = __onmousemove;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved within
	 * Getter for onmousemove
	 * @return onmousemove value from local variable or value bindings
	 */
	 public String getOnmousemove(  ){
	         if (null != this._onmousemove)
        {
            return this._onmousemove;
        	    }
        ValueBinding vb = getValueBinding("onmousemove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.Gmap";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[27];
        values[0] = super.saveState(context);
 	 	          values[1] = _lat;
	   	 	
  	 	          values[2] = _zoom;
	   	 	
  	 	          values[3] = _gmapKey;
	   	 	
  	 	          values[4] = _showGLargeMapControl;
	   	 	
    	 	          values[5] = _showGScaleControl;
	   	 	
  	 	          values[6] = _styleClass;
	   	 	
  	 	          values[7] = _onkeypress;
	   	 	
  	 	          values[8] = _ondblclick;
	   	 	
  	 	          values[9] = _enableDoubleClickZoom;
	   	 	
  	 	          values[10] = _style;
	   	 	
  	 	          values[11] = _mapType;
	   	 	
  	 	          values[12] = _onmouseover;
	   	 	
  	 	          values[13] = _enableInfoWindow;
	   	 	
  	 	          values[14] = _onkeyup;
	   	 	
  	 	          values[15] = _enableContinuousZoom;
	   	 	
  	 	          values[16] = _warningMessage;
	   	 	
  	 	          values[17] = _onclick;
	   	 	
  	 	          values[18] = _gmapVar;
	   	 	
  	 	          values[19] = _onmouseout;
	   	 	
  	 	          values[20] = _onkeydown;
	   	 	
  	 	          values[21] = _onmousedown;
	   	 	
  	 	          values[22] = _enableDragging;
	   	 	
  	 	          values[23] = _showGMapTypeControl;
	   	 	
  	 	          values[24] = _onmouseup;
	   	 	
   	 	          values[25] = _lng;
	   	 	
  	 	          values[26] = _onmousemove;
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
 	 	          _lat = (String)values[1] ;
	   	 	
  	 	          _zoom = (String)values[2] ;
	   	 	
  	 	          _gmapKey = (String)values[3] ;
	   	 	
  	 	          _showGLargeMapControl = (String)values[4] ;
	   	 	
    	 	          _showGScaleControl = (String)values[5] ;
	   	 	
  	 	          _styleClass = (String)values[6] ;
	   	 	
  	 	          _onkeypress = (String)values[7] ;
	   	 	
  	 	          _ondblclick = (String)values[8] ;
	   	 	
  	 	          _enableDoubleClickZoom = (String)values[9] ;
	   	 	
  	 	          _style = (String)values[10] ;
	   	 	
  	 	          _mapType = (String)values[11] ;
	   	 	
  	 	          _onmouseover = (String)values[12] ;
	   	 	
  	 	          _enableInfoWindow = (String)values[13] ;
	   	 	
  	 	          _onkeyup = (String)values[14] ;
	   	 	
  	 	          _enableContinuousZoom = (String)values[15] ;
	   	 	
  	 	          _warningMessage = (String)values[16] ;
	   	 	
  	 	          _onclick = (String)values[17] ;
	   	 	
  	 	          _gmapVar = (String)values[18] ;
	   	 	
  	 	          _onmouseout = (String)values[19] ;
	   	 	
  	 	          _onkeydown = (String)values[20] ;
	   	 	
  	 	          _onmousedown = (String)values[21] ;
	   	 	
  	 	          _enableDragging = (String)values[22] ;
	   	 	
  	 	          _showGMapTypeControl = (String)values[23] ;
	   	 	
  	 	          _onmouseup = (String)values[24] ;
	   	 	
   	 	          _lng = (String)values[25] ;
	   	 	
  	 	          _onmousemove = (String)values[26] ;
	   	 	
 	
		
	}	
// Utilites

}