/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UISimpleTogglePanel ;
import java.lang.Object ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.SimpleTogglePanel
 * Component-Family org.richfaces.SimpleTogglePanel
  	 * Renderer-Type org.richfaces.SimpleTogglePanelRenderer
  	 * Wrapper component with named facets. Every facet will be shown after activation
            corresponding toggleControl(the other will be hidden).
 */
 public class HtmlSimpleTogglePanel extends org.richfaces.component.UISimpleTogglePanel {

  public static final String COMPONENT_TYPE = "org.richfaces.SimpleTogglePanel";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlSimpleTogglePanel (){
  	  	setRendererType("org.richfaces.SimpleTogglePanelRenderer");
  	  }

// Component properties fields
  	/**
	 * width
	 * Width of a simple toggle panel might be defined as pixels or in percents.
	    	By default width is not defined
	 */
	 	 private String  _width = null; /* Default is "100%"*/
	 	   	/**
	 * oncomplete
	 * JavaScript code for call after request completed on client side
	 */
	 	 private String  _oncomplete = null; /* Default is null*/
	 	  	/**
	 * bodyClass
	 * A class that defines a style for a panel header
	 */
	 	 private String  _bodyClass = null; /* Default is null*/
	 	   	/**
	 * reRender
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 */
	 	 private Object  _reRender = null; /* Default is null*/
	 	   	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * bypassUpdates
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 */
	 	 private boolean  _bypassUpdates = false;		
	/**
	 * Flag indicated what bypassUpdates is set.
	 */
	 private boolean _bypassUpdatesSet = false;	
	 	  	/**
	 * switchType
	 * Facets switch algorithm: "client", "server"(default), "ajax".
	 */
	 	 private String  _switchType = null; /* Default is null*/
	 	  	/**
	 * height
	 * Height of a simple toggle panel content area might be defined as pixels or in percents.
	    		By default height is not defined
	 */
	 	 private String  _height = null; /* Default is null*/
	 	  	/**
	 * onkeypress
	 * HTML: a script expression; a key is pressed and released
	 */
	 	 private String  _onkeypress = null; /* Default is null*/
	 	  	/**
	 * limitToList
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 */
	 	 private boolean  _limitToList = false;		
	/**
	 * Flag indicated what limitToList is set.
	 */
	 private boolean _limitToListSet = false;	
	 	  	/**
	 * ondblclick
	 * HTML: a script expression; a pointer button is double-clicked
	 */
	 	 private String  _ondblclick = null; /* Default is null*/
	 	  	/**
	 * ajaxSingle
	 * if true , submits ONLY one field/link, instead of all form controls.
	 */
	 	 private boolean  _ajaxSingle = false;		
	/**
	 * Flag indicated what ajaxSingle is set.
	 */
	 private boolean _ajaxSingleSet = false;	
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * onmouseover
	 * HTML: a script expression; a pointer is moved onto
	 */
	 	 private String  _onmouseover = null; /* Default is null*/
	 	  	/**
	 * onkeyup
	 * HTML: a script expression; a key is released
	 */
	 	 private String  _onkeyup = null; /* Default is null*/
	 	    	/**
	 * timeout
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 */
	 	 private int  _timeout = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what timeout is set.
	 */
	 private boolean _timeoutSet = false;	
	 	   	/**
	 * onclick
	 * HTML: a script expression; a pointer button is clicked
	 */
	 	 private String  _onclick = null; /* Default is null*/
	 	  	/**
	 * headerClass
	 * Class that defines the style for panel header
	 */
	 	 private String  _headerClass = null; /* Default is null*/
	 	  	/**
	 * status
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 */
	 	 private String  _status = null; /* Default is null*/
	 	  	/**
	 * onmouseout
	 * HTML: a script expression; a pointer is moved away
	 */
	 	 private String  _onmouseout = null; /* Default is null*/
	 	  	/**
	 * onkeydown
	 * HTML: a script expression; a key is pressed down
	 */
	 	 private String  _onkeydown = null; /* Default is null*/
	 	  	/**
	 * onmousedown
	 * HTML: script expression; a pointer button is pressed down
	 */
	 	 private String  _onmousedown = null; /* Default is null*/
	 	  	/**
	 * requestDelay
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 */
	 	 private int  _requestDelay = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what requestDelay is set.
	 */
	 private boolean _requestDelaySet = false;	
	 	  	/**
	 * opened
	 * A false value for this attribute makes a panel closed as default
	 */
	 	 private boolean  _opened = true;		
	/**
	 * Flag indicated what opened is set.
	 */
	 private boolean _openedSet = false;	
	 	  	/**
	 * eventsQueue
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 */
	 	 private String  _eventsQueue = null; /* Default is null*/
	 	  	/**
	 * label
	 * Marker to be rendered on a panel header
	 */
	 	 private String  _label = null; /* Default is null*/
	 	   	/**
	 * data
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 */
	 	 private Object  _data = null; /* Default is null*/
	 	  	/**
	 * onmouseup
	 * HTML: script expression; a pointer button is released
	 */
	 	 private String  _onmouseup = null; /* Default is null*/
	 	  	/**
	 * ignoreDupResponses
	 * If true, unfinished request will be aborted on new event
	 */
	 	 private boolean  _ignoreDupResponses = false;		
	/**
	 * Flag indicated what ignoreDupResponses is set.
	 */
	 private boolean _ignoreDupResponsesSet = false;	
	 	   	/**
	 * onmousemove
	 * HTML: a script expression; a pointer is moved within
	 */
	 	 private String  _onmousemove = null; /* Default is null*/
	 	 
// Getters-setters
  	/*
	 * Width of a simple toggle panel might be defined as pixels or in percents.
	    	By default width is not defined
	 * Setter for width
	 * @param width - new value
	 */
	 public void setWidth( String  __width ){
		this._width = __width;
	 	 }


	/*
	 * Width of a simple toggle panel might be defined as pixels or in percents.
	    	By default width is not defined
	 * Getter for width
	 * @return width value from local variable or value bindings
	 */
	 public String getWidth(  ){
	         if (null != this._width)
        {
            return this._width;
        	    }
        ValueBinding vb = getValueBinding("width");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "100%";
        }
	 	 }
	    	/*
	 * JavaScript code for call after request completed on client side
	 * Setter for oncomplete
	 * @param oncomplete - new value
	 */
	 public void setOncomplete( String  __oncomplete ){
		this._oncomplete = __oncomplete;
	 	 }


	/*
	 * JavaScript code for call after request completed on client side
	 * Getter for oncomplete
	 * @return oncomplete value from local variable or value bindings
	 */
	 public String getOncomplete(  ){
	         if (null != this._oncomplete)
        {
            return this._oncomplete;
        	    }
        ValueBinding vb = getValueBinding("oncomplete");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A class that defines a style for a panel header
	 * Setter for bodyClass
	 * @param bodyClass - new value
	 */
	 public void setBodyClass( String  __bodyClass ){
		this._bodyClass = __bodyClass;
	 	 }


	/*
	 * A class that defines a style for a panel header
	 * Getter for bodyClass
	 * @return bodyClass value from local variable or value bindings
	 */
	 public String getBodyClass(  ){
	         if (null != this._bodyClass)
        {
            return this._bodyClass;
        	    }
        ValueBinding vb = getValueBinding("bodyClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 * Setter for reRender
	 * @param reRender - new value
	 */
	 public void setReRender( Object  __reRender ){
		this._reRender = __reRender;
	 	 }


	/*
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 * Getter for reRender
	 * @return reRender value from local variable or value bindings
	 */
	 public Object getReRender(  ){
	         if (null != this._reRender)
        {
            return this._reRender;
        	    }
        ValueBinding vb = getValueBinding("reRender");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 * Setter for bypassUpdates
	 * @param bypassUpdates - new value
	 */
	 public void setBypassUpdates( boolean  __bypassUpdates ){
		this._bypassUpdates = __bypassUpdates;
	 		this._bypassUpdatesSet = true;
	 	 }


	/*
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 * Getter for bypassUpdates
	 * @return bypassUpdates value from local variable or value bindings
	 */
	 public boolean isBypassUpdates(  ){
	 		 if(this._bypassUpdatesSet){
			return this._bypassUpdates;
		 }
    	ValueBinding vb = getValueBinding("bypassUpdates");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._bypassUpdates;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._bypassUpdates);
    	}
	 	 }
	   	/*
	 * Facets switch algorithm: "client", "server"(default), "ajax".
	 * Setter for switchType
	 * @param switchType - new value
	 */
	 public void setSwitchType( String  __switchType ){
		this._switchType = __switchType;
	 	 }


	/*
	 * Facets switch algorithm: "client", "server"(default), "ajax".
	 * Getter for switchType
	 * @return switchType value from local variable or value bindings
	 */
	 public String getSwitchType(  ){
	         if (null != this._switchType)
        {
            return this._switchType;
        	    }
        ValueBinding vb = getValueBinding("switchType");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Height of a simple toggle panel content area might be defined as pixels or in percents.
	    		By default height is not defined
	 * Setter for height
	 * @param height - new value
	 */
	 public void setHeight( String  __height ){
		this._height = __height;
	 	 }


	/*
	 * Height of a simple toggle panel content area might be defined as pixels or in percents.
	    		By default height is not defined
	 * Getter for height
	 * @return height value from local variable or value bindings
	 */
	 public String getHeight(  ){
	         if (null != this._height)
        {
            return this._height;
        	    }
        ValueBinding vb = getValueBinding("height");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed and released
	 * Setter for onkeypress
	 * @param onkeypress - new value
	 */
	 public void setOnkeypress( String  __onkeypress ){
		this._onkeypress = __onkeypress;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed and released
	 * Getter for onkeypress
	 * @return onkeypress value from local variable or value bindings
	 */
	 public String getOnkeypress(  ){
	         if (null != this._onkeypress)
        {
            return this._onkeypress;
        	    }
        ValueBinding vb = getValueBinding("onkeypress");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 * Setter for limitToList
	 * @param limitToList - new value
	 */
	 public void setLimitToList( boolean  __limitToList ){
		this._limitToList = __limitToList;
	 		this._limitToListSet = true;
	 	 }


	/*
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 * Getter for limitToList
	 * @return limitToList value from local variable or value bindings
	 */
	 public boolean isLimitToList(  ){
	 		 if(this._limitToListSet){
			return this._limitToList;
		 }
    	ValueBinding vb = getValueBinding("limitToList");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._limitToList;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._limitToList);
    	}
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Setter for ondblclick
	 * @param ondblclick - new value
	 */
	 public void setOndblclick( String  __ondblclick ){
		this._ondblclick = __ondblclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Getter for ondblclick
	 * @return ondblclick value from local variable or value bindings
	 */
	 public String getOndblclick(  ){
	         if (null != this._ondblclick)
        {
            return this._ondblclick;
        	    }
        ValueBinding vb = getValueBinding("ondblclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * if true , submits ONLY one field/link, instead of all form controls.
	 * Setter for ajaxSingle
	 * @param ajaxSingle - new value
	 */
	 public void setAjaxSingle( boolean  __ajaxSingle ){
		this._ajaxSingle = __ajaxSingle;
	 		this._ajaxSingleSet = true;
	 	 }


	/*
	 * if true , submits ONLY one field/link, instead of all form controls.
	 * Getter for ajaxSingle
	 * @return ajaxSingle value from local variable or value bindings
	 */
	 public boolean isAjaxSingle(  ){
	 		 if(this._ajaxSingleSet){
			return this._ajaxSingle;
		 }
    	ValueBinding vb = getValueBinding("ajaxSingle");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ajaxSingle;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ajaxSingle);
    	}
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Setter for onmouseover
	 * @param onmouseover - new value
	 */
	 public void setOnmouseover( String  __onmouseover ){
		this._onmouseover = __onmouseover;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Getter for onmouseover
	 * @return onmouseover value from local variable or value bindings
	 */
	 public String getOnmouseover(  ){
	         if (null != this._onmouseover)
        {
            return this._onmouseover;
        	    }
        ValueBinding vb = getValueBinding("onmouseover");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is released
	 * Setter for onkeyup
	 * @param onkeyup - new value
	 */
	 public void setOnkeyup( String  __onkeyup ){
		this._onkeyup = __onkeyup;
	 	 }


	/*
	 * HTML: a script expression; a key is released
	 * Getter for onkeyup
	 * @return onkeyup value from local variable or value bindings
	 */
	 public String getOnkeyup(  ){
	         if (null != this._onkeyup)
        {
            return this._onkeyup;
        	    }
        ValueBinding vb = getValueBinding("onkeyup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Setter for timeout
	 * @param timeout - new value
	 */
	 public void setTimeout( int  __timeout ){
		this._timeout = __timeout;
	 		this._timeoutSet = true;
	 	 }


	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Getter for timeout
	 * @return timeout value from local variable or value bindings
	 */
	 public int getTimeout(  ){
	 		 if(this._timeoutSet){
			return this._timeout;
		 }
    	ValueBinding vb = getValueBinding("timeout");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._timeout;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._timeout);
    	}
	 	 }
	    	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Setter for onclick
	 * @param onclick - new value
	 */
	 public void setOnclick( String  __onclick ){
		this._onclick = __onclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Getter for onclick
	 * @return onclick value from local variable or value bindings
	 */
	 public String getOnclick(  ){
	         if (null != this._onclick)
        {
            return this._onclick;
        	    }
        ValueBinding vb = getValueBinding("onclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Class that defines the style for panel header
	 * Setter for headerClass
	 * @param headerClass - new value
	 */
	 public void setHeaderClass( String  __headerClass ){
		this._headerClass = __headerClass;
	 	 }


	/*
	 * Class that defines the style for panel header
	 * Getter for headerClass
	 * @return headerClass value from local variable or value bindings
	 */
	 public String getHeaderClass(  ){
	         if (null != this._headerClass)
        {
            return this._headerClass;
        	    }
        ValueBinding vb = getValueBinding("headerClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 * Setter for status
	 * @param status - new value
	 */
	 public void setStatus( String  __status ){
		this._status = __status;
	 	 }


	/*
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 * Getter for status
	 * @return status value from local variable or value bindings
	 */
	 public String getStatus(  ){
	         if (null != this._status)
        {
            return this._status;
        	    }
        ValueBinding vb = getValueBinding("status");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved away
	 * Setter for onmouseout
	 * @param onmouseout - new value
	 */
	 public void setOnmouseout( String  __onmouseout ){
		this._onmouseout = __onmouseout;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved away
	 * Getter for onmouseout
	 * @return onmouseout value from local variable or value bindings
	 */
	 public String getOnmouseout(  ){
	         if (null != this._onmouseout)
        {
            return this._onmouseout;
        	    }
        ValueBinding vb = getValueBinding("onmouseout");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed down
	 * Setter for onkeydown
	 * @param onkeydown - new value
	 */
	 public void setOnkeydown( String  __onkeydown ){
		this._onkeydown = __onkeydown;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed down
	 * Getter for onkeydown
	 * @return onkeydown value from local variable or value bindings
	 */
	 public String getOnkeydown(  ){
	         if (null != this._onkeydown)
        {
            return this._onkeydown;
        	    }
        ValueBinding vb = getValueBinding("onkeydown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Setter for onmousedown
	 * @param onmousedown - new value
	 */
	 public void setOnmousedown( String  __onmousedown ){
		this._onmousedown = __onmousedown;
	 	 }


	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Getter for onmousedown
	 * @return onmousedown value from local variable or value bindings
	 */
	 public String getOnmousedown(  ){
	         if (null != this._onmousedown)
        {
            return this._onmousedown;
        	    }
        ValueBinding vb = getValueBinding("onmousedown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 * Setter for requestDelay
	 * @param requestDelay - new value
	 */
	 public void setRequestDelay( int  __requestDelay ){
		this._requestDelay = __requestDelay;
	 		this._requestDelaySet = true;
	 	 }


	/*
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 * Getter for requestDelay
	 * @return requestDelay value from local variable or value bindings
	 */
	 public int getRequestDelay(  ){
	 		 if(this._requestDelaySet){
			return this._requestDelay;
		 }
    	ValueBinding vb = getValueBinding("requestDelay");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._requestDelay;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._requestDelay);
    	}
	 	 }
	   	/*
	 * A false value for this attribute makes a panel closed as default
	 * Setter for opened
	 * @param opened - new value
	 */
	 public void setOpened( boolean  __opened ){
		this._opened = __opened;
	 		this._openedSet = true;
	 	 }


	/*
	 * A false value for this attribute makes a panel closed as default
	 * Getter for opened
	 * @return opened value from local variable or value bindings
	 */
	 public boolean isOpened(  ){
	 		 if(this._openedSet){
			return this._opened;
		 }
    	ValueBinding vb = getValueBinding("opened");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._opened;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._opened);
    	}
	 	 }
	   	/*
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 * Setter for eventsQueue
	 * @param eventsQueue - new value
	 */
	 public void setEventsQueue( String  __eventsQueue ){
		this._eventsQueue = __eventsQueue;
	 	 }


	/*
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 * Getter for eventsQueue
	 * @return eventsQueue value from local variable or value bindings
	 */
	 public String getEventsQueue(  ){
	         if (null != this._eventsQueue)
        {
            return this._eventsQueue;
        	    }
        ValueBinding vb = getValueBinding("eventsQueue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Marker to be rendered on a panel header
	 * Setter for label
	 * @param label - new value
	 */
	 public void setLabel( String  __label ){
		this._label = __label;
	 	 }


	/*
	 * Marker to be rendered on a panel header
	 * Getter for label
	 * @return label value from local variable or value bindings
	 */
	 public String getLabel(  ){
	         if (null != this._label)
        {
            return this._label;
        	    }
        ValueBinding vb = getValueBinding("label");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Setter for data
	 * @param data - new value
	 */
	 public void setData( Object  __data ){
		this._data = __data;
	 	 }


	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Getter for data
	 * @return data value from local variable or value bindings
	 */
	 public Object getData(  ){
	         if (null != this._data)
        {
            return this._data;
        	    }
        ValueBinding vb = getValueBinding("data");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is released
	 * Setter for onmouseup
	 * @param onmouseup - new value
	 */
	 public void setOnmouseup( String  __onmouseup ){
		this._onmouseup = __onmouseup;
	 	 }


	/*
	 * HTML: script expression; a pointer button is released
	 * Getter for onmouseup
	 * @return onmouseup value from local variable or value bindings
	 */
	 public String getOnmouseup(  ){
	         if (null != this._onmouseup)
        {
            return this._onmouseup;
        	    }
        ValueBinding vb = getValueBinding("onmouseup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If true, unfinished request will be aborted on new event
	 * Setter for ignoreDupResponses
	 * @param ignoreDupResponses - new value
	 */
	 public void setIgnoreDupResponses( boolean  __ignoreDupResponses ){
		this._ignoreDupResponses = __ignoreDupResponses;
	 		this._ignoreDupResponsesSet = true;
	 	 }


	/*
	 * If true, unfinished request will be aborted on new event
	 * Getter for ignoreDupResponses
	 * @return ignoreDupResponses value from local variable or value bindings
	 */
	 public boolean isIgnoreDupResponses(  ){
	 		 if(this._ignoreDupResponsesSet){
			return this._ignoreDupResponses;
		 }
    	ValueBinding vb = getValueBinding("ignoreDupResponses");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ignoreDupResponses;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ignoreDupResponses);
    	}
	 	 }
	    	/*
	 * HTML: a script expression; a pointer is moved within
	 * Setter for onmousemove
	 * @param onmousemove - new value
	 */
	 public void setOnmousemove( String  __onmousemove ){
		this._onmousemove = __onmousemove;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved within
	 * Getter for onmousemove
	 * @return onmousemove value from local variable or value bindings
	 */
	 public String getOnmousemove(  ){
	         if (null != this._onmousemove)
        {
            return this._onmousemove;
        	    }
        ValueBinding vb = getValueBinding("onmousemove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.SimpleTogglePanel";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[38];
        values[0] = super.saveState(context);
  	 	          values[1] = _width;
	   	 	
   	 	          values[2] = _oncomplete;
	   	 	
  	 	          values[3] = _bodyClass;
	   	 	
   	 	          values[4] = _reRender;
	   	 	
   	 	          values[5] = _styleClass;
	   	 	
  	        values[6] = new Boolean(_bypassUpdates);
	   	   values[7] = Boolean.valueOf(_bypassUpdatesSet);	
	   	 	
  	 	          values[8] = _switchType;
	   	 	
  	 	          values[9] = _height;
	   	 	
  	 	          values[10] = _onkeypress;
	   	 	
  	        values[11] = new Boolean(_limitToList);
	   	   values[12] = Boolean.valueOf(_limitToListSet);	
	   	 	
  	 	          values[13] = _ondblclick;
	   	 	
  	        values[14] = new Boolean(_ajaxSingle);
	   	   values[15] = Boolean.valueOf(_ajaxSingleSet);	
	   	 	
  	 	          values[16] = _style;
	   	 	
  	 	          values[17] = _onmouseover;
	   	 	
  	 	          values[18] = _onkeyup;
	   	 	
    	        values[19] = new Integer(_timeout);
	   	   values[20] = Boolean.valueOf(_timeoutSet);	
	   	 	
   	 	          values[21] = _onclick;
	   	 	
  	 	          values[22] = _headerClass;
	   	 	
  	 	          values[23] = _status;
	   	 	
  	 	          values[24] = _onmouseout;
	   	 	
  	 	          values[25] = _onkeydown;
	   	 	
  	 	          values[26] = _onmousedown;
	   	 	
  	        values[27] = new Integer(_requestDelay);
	   	   values[28] = Boolean.valueOf(_requestDelaySet);	
	   	 	
  	        values[29] = new Boolean(_opened);
	   	   values[30] = Boolean.valueOf(_openedSet);	
	   	 	
  	 	          values[31] = _eventsQueue;
	   	 	
  	 	          values[32] = _label;
	   	 	
   	 	          values[33] = _data;
	   	 	
  	 	          values[34] = _onmouseup;
	   	 	
  	        values[35] = new Boolean(_ignoreDupResponses);
	   	   values[36] = Boolean.valueOf(_ignoreDupResponsesSet);	
	   	 	
   	 	          values[37] = _onmousemove;
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	 	          _width = (String)values[1] ;
	   	 	
   	 	          _oncomplete = (String)values[2] ;
	   	 	
  	 	          _bodyClass = (String)values[3] ;
	   	 	
   	 	          _reRender = (Object)values[4] ;
	   	 	
   	 	          _styleClass = (String)values[5] ;
	   	 	
  	        _bypassUpdates = ((Boolean)values[6]).booleanValue();
	   	   _bypassUpdatesSet = ((Boolean)values[7]).booleanValue();	
	   	 	
  	 	          _switchType = (String)values[8] ;
	   	 	
  	 	          _height = (String)values[9] ;
	   	 	
  	 	          _onkeypress = (String)values[10] ;
	   	 	
  	        _limitToList = ((Boolean)values[11]).booleanValue();
	   	   _limitToListSet = ((Boolean)values[12]).booleanValue();	
	   	 	
  	 	          _ondblclick = (String)values[13] ;
	   	 	
  	        _ajaxSingle = ((Boolean)values[14]).booleanValue();
	   	   _ajaxSingleSet = ((Boolean)values[15]).booleanValue();	
	   	 	
  	 	          _style = (String)values[16] ;
	   	 	
  	 	          _onmouseover = (String)values[17] ;
	   	 	
  	 	          _onkeyup = (String)values[18] ;
	   	 	
    	        _timeout = ((Integer)values[19]).intValue();
	   	   _timeoutSet = ((Boolean)values[20]).booleanValue();	
	   	 	
   	 	          _onclick = (String)values[21] ;
	   	 	
  	 	          _headerClass = (String)values[22] ;
	   	 	
  	 	          _status = (String)values[23] ;
	   	 	
  	 	          _onmouseout = (String)values[24] ;
	   	 	
  	 	          _onkeydown = (String)values[25] ;
	   	 	
  	 	          _onmousedown = (String)values[26] ;
	   	 	
  	        _requestDelay = ((Integer)values[27]).intValue();
	   	   _requestDelaySet = ((Boolean)values[28]).booleanValue();	
	   	 	
  	        _opened = ((Boolean)values[29]).booleanValue();
	   	   _openedSet = ((Boolean)values[30]).booleanValue();	
	   	 	
  	 	          _eventsQueue = (String)values[31] ;
	   	 	
  	 	          _label = (String)values[32] ;
	   	 	
   	 	          _data = (Object)values[33] ;
	   	 	
  	 	          _onmouseup = (String)values[34] ;
	   	 	
  	        _ignoreDupResponses = ((Boolean)values[35]).booleanValue();
	   	   _ignoreDupResponsesSet = ((Boolean)values[36]).booleanValue();	
	   	 	
   	 	          _onmousemove = (String)values[37] ;
	   	 	
 	
		
	}	
// Utilites

}