/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import org.richfaces.component.UITabPanel ;
import java.lang.String ;
import java.lang.Object ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.TabPanel
 * Component-Family org.richfaces.TabPanel
  	 * Renderer-Type org.richfaces.TabPanelRenderer
  	 * A tab panel displaying tabs for grouping content of a panel.
 */
 public class HtmlTabPanel extends org.richfaces.component.UITabPanel {

  public static final String COMPONENT_TYPE = "org.richfaces.TabPanel";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlTabPanel (){
  	  	setRendererType("org.richfaces.TabPanelRenderer");
  	  }

// Component properties fields
  	/**
	 * width
	 * Width of a tab panel defined in pixels or in percents. 
	    	The default value is 100%
	 */
	 	 private String  _width = null; /* Default is null*/
	 	  	/**
	 * contentStyle
	 * A CSS style is for the content of a tab panel
	 */
	 	 private String  _contentStyle = null; /* Default is null*/
	 	  	/**
	 * title
	 * Advisory title information about markup elements generated for this component
	 */
	 	 private String  _title = null; /* Default is null*/
	 	   	/**
	 * activeTabClass
	 * A CSS class to be applied to an active tab
	 */
	 	 private String  _activeTabClass = null; /* Default is null*/
	 	   	/**
	 * tabClass
	 * A CSS class to be applied to all tabs
	 */
	 	 private String  _tabClass = null; /* Default is null*/
	 	    	/**
	 * dir
	 * Alternate textual description of the element rendered by this component
	 */
	 	 private String  _dir = null; /* Default is null*/
	 	   	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * switchType
	 * Tab switch algorithm: "client", "server"(default), "ajax"
	 */
	 	 private String  _switchType = null; /* Default is DEFAULT_METHOD*/
	 	  	/**
	 * height
	 * Height of a tab panel defined in pixels or in percents
	 */
	 	 private String  _height = null; /* Default is null*/
	 	  	/**
	 * onkeypress
	 * HTML: a script expression; a key is pressed and released
	 */
	 	 private String  _onkeypress = null; /* Default is null*/
	 	  	/**
	 * ondblclick
	 * HTML: a script expression; a pointer button is double-clicked
	 */
	 	 private String  _ondblclick = null; /* Default is null*/
	 	  	/**
	 * headerAlignment
	 * Sets tab headers alignment. It can be "left", "center" or "right".
	    	"left" is used by default
	 */
	 	 private String  _headerAlignment = null; /* Default is "left"*/
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * onmouseover
	 * HTML: a script expression; a pointer is moved onto
	 */
	 	 private String  _onmouseover = null; /* Default is null*/
	 	   	/**
	 * onkeyup
	 * HTML: a script expression; a key is released
	 */
	 	 private String  _onkeyup = null; /* Default is null*/
	 	  	/**
	 * disabledTabClass
	 * A CSS class to be applied to a disabled tab
	 */
	 	 private String  _disabledTabClass = null; /* Default is null*/
	 	    	/**
	 * lang
	 * Code describing the language used in the generated markup for this component
	 */
	 	 private String  _lang = null; /* Default is null*/
	 	   	/**
	 * onclick
	 * HTML: a script expression; a pointer button is clicked
	 */
	 	 private String  _onclick = null; /* Default is null*/
	 	  	/**
	 * inactiveTabClass
	 * CSS class to be applied to an inactive (but not disabled) tab
	 */
	 	 private String  _inactiveTabClass = null; /* Default is null*/
	 	   	/**
	 * onmouseout
	 * HTML: a script expression; a pointer is moved away
	 */
	 	 private String  _onmouseout = null; /* Default is null*/
	 	  	/**
	 * onkeydown
	 * HTML: a script expression; a key is pressed down
	 */
	 	 private String  _onkeydown = null; /* Default is null*/
	 	  	/**
	 * onmousedown
	 * HTML: script expression; a pointer button is pressed down
	 */
	 	 private String  _onmousedown = null; /* Default is null*/
	 	  	/**
	 * selectedTab
	 * selectedTab
	 */
	 	 private Object  _selectedTab = null; /* Default is null*/
	 	  	/**
	 * contentClass
	 * A CSS class for content of a tab panel
	 */
	 	 private String  _contentClass = null; /* Default is null*/
	 	     	/**
	 * onmouseup
	 * HTML: script expression; a pointer button is released
	 */
	 	 private String  _onmouseup = null; /* Default is null*/
	 	   	/**
	 * onmousemove
	 * HTML: a script expression; a pointer is moved within
	 */
	 	 private String  _onmousemove = null; /* Default is null*/
	 	  	/**
	 * headerSpacing
	 * Sets tab headers spacing. It should be a valid size unit expression
	 */
	 	 private String  _headerSpacing = null; /* Default is "1px"*/
	 	 
// Getters-setters
  	/*
	 * Width of a tab panel defined in pixels or in percents. 
	    	The default value is 100%
	 * Setter for width
	 * @param width - new value
	 */
	 public void setWidth( String  __width ){
		this._width = __width;
	 	 }


	/*
	 * Width of a tab panel defined in pixels or in percents. 
	    	The default value is 100%
	 * Getter for width
	 * @return width value from local variable or value bindings
	 */
	 public String getWidth(  ){
	         if (null != this._width)
        {
            return this._width;
        	    }
        ValueBinding vb = getValueBinding("width");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A CSS style is for the content of a tab panel
	 * Setter for contentStyle
	 * @param contentStyle - new value
	 */
	 public void setContentStyle( String  __contentStyle ){
		this._contentStyle = __contentStyle;
	 	 }


	/*
	 * A CSS style is for the content of a tab panel
	 * Getter for contentStyle
	 * @return contentStyle value from local variable or value bindings
	 */
	 public String getContentStyle(  ){
	         if (null != this._contentStyle)
        {
            return this._contentStyle;
        	    }
        ValueBinding vb = getValueBinding("contentStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Advisory title information about markup elements generated for this component
	 * Setter for title
	 * @param title - new value
	 */
	 public void setTitle( String  __title ){
		this._title = __title;
	 	 }


	/*
	 * Advisory title information about markup elements generated for this component
	 * Getter for title
	 * @return title value from local variable or value bindings
	 */
	 public String getTitle(  ){
	         if (null != this._title)
        {
            return this._title;
        	    }
        ValueBinding vb = getValueBinding("title");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * A CSS class to be applied to an active tab
	 * Setter for activeTabClass
	 * @param activeTabClass - new value
	 */
	 public void setActiveTabClass( String  __activeTabClass ){
		this._activeTabClass = __activeTabClass;
	 	 }


	/*
	 * A CSS class to be applied to an active tab
	 * Getter for activeTabClass
	 * @return activeTabClass value from local variable or value bindings
	 */
	 public String getActiveTabClass(  ){
	         if (null != this._activeTabClass)
        {
            return this._activeTabClass;
        	    }
        ValueBinding vb = getValueBinding("activeTabClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * A CSS class to be applied to all tabs
	 * Setter for tabClass
	 * @param tabClass - new value
	 */
	 public void setTabClass( String  __tabClass ){
		this._tabClass = __tabClass;
	 	 }


	/*
	 * A CSS class to be applied to all tabs
	 * Getter for tabClass
	 * @return tabClass value from local variable or value bindings
	 */
	 public String getTabClass(  ){
	         if (null != this._tabClass)
        {
            return this._tabClass;
        	    }
        ValueBinding vb = getValueBinding("tabClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * Alternate textual description of the element rendered by this component
	 * Setter for dir
	 * @param dir - new value
	 */
	 public void setDir( String  __dir ){
		this._dir = __dir;
	 	 }


	/*
	 * Alternate textual description of the element rendered by this component
	 * Getter for dir
	 * @return dir value from local variable or value bindings
	 */
	 public String getDir(  ){
	         if (null != this._dir)
        {
            return this._dir;
        	    }
        ValueBinding vb = getValueBinding("dir");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Tab switch algorithm: "client", "server"(default), "ajax"
	 * Setter for switchType
	 * @param switchType - new value
	 */
	 public void setSwitchType( String  __switchType ){
		this._switchType = __switchType;
	 	 }


	/*
	 * Tab switch algorithm: "client", "server"(default), "ajax"
	 * Getter for switchType
	 * @return switchType value from local variable or value bindings
	 */
	 public String getSwitchType(  ){
	         if (null != this._switchType)
        {
            return this._switchType;
        	    }
        ValueBinding vb = getValueBinding("switchType");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return DEFAULT_METHOD;
        }
	 	 }
	   	/*
	 * Height of a tab panel defined in pixels or in percents
	 * Setter for height
	 * @param height - new value
	 */
	 public void setHeight( String  __height ){
		this._height = __height;
	 	 }


	/*
	 * Height of a tab panel defined in pixels or in percents
	 * Getter for height
	 * @return height value from local variable or value bindings
	 */
	 public String getHeight(  ){
	         if (null != this._height)
        {
            return this._height;
        	    }
        ValueBinding vb = getValueBinding("height");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed and released
	 * Setter for onkeypress
	 * @param onkeypress - new value
	 */
	 public void setOnkeypress( String  __onkeypress ){
		this._onkeypress = __onkeypress;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed and released
	 * Getter for onkeypress
	 * @return onkeypress value from local variable or value bindings
	 */
	 public String getOnkeypress(  ){
	         if (null != this._onkeypress)
        {
            return this._onkeypress;
        	    }
        ValueBinding vb = getValueBinding("onkeypress");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Setter for ondblclick
	 * @param ondblclick - new value
	 */
	 public void setOndblclick( String  __ondblclick ){
		this._ondblclick = __ondblclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Getter for ondblclick
	 * @return ondblclick value from local variable or value bindings
	 */
	 public String getOndblclick(  ){
	         if (null != this._ondblclick)
        {
            return this._ondblclick;
        	    }
        ValueBinding vb = getValueBinding("ondblclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Sets tab headers alignment. It can be "left", "center" or "right".
	    	"left" is used by default
	 * Setter for headerAlignment
	 * @param headerAlignment - new value
	 */
	 public void setHeaderAlignment( String  __headerAlignment ){
		this._headerAlignment = __headerAlignment;
	 	 }


	/*
	 * Sets tab headers alignment. It can be "left", "center" or "right".
	    	"left" is used by default
	 * Getter for headerAlignment
	 * @return headerAlignment value from local variable or value bindings
	 */
	 public String getHeaderAlignment(  ){
	         if (null != this._headerAlignment)
        {
            return this._headerAlignment;
        	    }
        ValueBinding vb = getValueBinding("headerAlignment");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "left";
        }
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Setter for onmouseover
	 * @param onmouseover - new value
	 */
	 public void setOnmouseover( String  __onmouseover ){
		this._onmouseover = __onmouseover;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Getter for onmouseover
	 * @return onmouseover value from local variable or value bindings
	 */
	 public String getOnmouseover(  ){
	         if (null != this._onmouseover)
        {
            return this._onmouseover;
        	    }
        ValueBinding vb = getValueBinding("onmouseover");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * HTML: a script expression; a key is released
	 * Setter for onkeyup
	 * @param onkeyup - new value
	 */
	 public void setOnkeyup( String  __onkeyup ){
		this._onkeyup = __onkeyup;
	 	 }


	/*
	 * HTML: a script expression; a key is released
	 * Getter for onkeyup
	 * @return onkeyup value from local variable or value bindings
	 */
	 public String getOnkeyup(  ){
	         if (null != this._onkeyup)
        {
            return this._onkeyup;
        	    }
        ValueBinding vb = getValueBinding("onkeyup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A CSS class to be applied to a disabled tab
	 * Setter for disabledTabClass
	 * @param disabledTabClass - new value
	 */
	 public void setDisabledTabClass( String  __disabledTabClass ){
		this._disabledTabClass = __disabledTabClass;
	 	 }


	/*
	 * A CSS class to be applied to a disabled tab
	 * Getter for disabledTabClass
	 * @return disabledTabClass value from local variable or value bindings
	 */
	 public String getDisabledTabClass(  ){
	         if (null != this._disabledTabClass)
        {
            return this._disabledTabClass;
        	    }
        ValueBinding vb = getValueBinding("disabledTabClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * Code describing the language used in the generated markup for this component
	 * Setter for lang
	 * @param lang - new value
	 */
	 public void setLang( String  __lang ){
		this._lang = __lang;
	 	 }


	/*
	 * Code describing the language used in the generated markup for this component
	 * Getter for lang
	 * @return lang value from local variable or value bindings
	 */
	 public String getLang(  ){
	         if (null != this._lang)
        {
            return this._lang;
        	    }
        ValueBinding vb = getValueBinding("lang");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Setter for onclick
	 * @param onclick - new value
	 */
	 public void setOnclick( String  __onclick ){
		this._onclick = __onclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Getter for onclick
	 * @return onclick value from local variable or value bindings
	 */
	 public String getOnclick(  ){
	         if (null != this._onclick)
        {
            return this._onclick;
        	    }
        ValueBinding vb = getValueBinding("onclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * CSS class to be applied to an inactive (but not disabled) tab
	 * Setter for inactiveTabClass
	 * @param inactiveTabClass - new value
	 */
	 public void setInactiveTabClass( String  __inactiveTabClass ){
		this._inactiveTabClass = __inactiveTabClass;
	 	 }


	/*
	 * CSS class to be applied to an inactive (but not disabled) tab
	 * Getter for inactiveTabClass
	 * @return inactiveTabClass value from local variable or value bindings
	 */
	 public String getInactiveTabClass(  ){
	         if (null != this._inactiveTabClass)
        {
            return this._inactiveTabClass;
        	    }
        ValueBinding vb = getValueBinding("inactiveTabClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * HTML: a script expression; a pointer is moved away
	 * Setter for onmouseout
	 * @param onmouseout - new value
	 */
	 public void setOnmouseout( String  __onmouseout ){
		this._onmouseout = __onmouseout;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved away
	 * Getter for onmouseout
	 * @return onmouseout value from local variable or value bindings
	 */
	 public String getOnmouseout(  ){
	         if (null != this._onmouseout)
        {
            return this._onmouseout;
        	    }
        ValueBinding vb = getValueBinding("onmouseout");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed down
	 * Setter for onkeydown
	 * @param onkeydown - new value
	 */
	 public void setOnkeydown( String  __onkeydown ){
		this._onkeydown = __onkeydown;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed down
	 * Getter for onkeydown
	 * @return onkeydown value from local variable or value bindings
	 */
	 public String getOnkeydown(  ){
	         if (null != this._onkeydown)
        {
            return this._onkeydown;
        	    }
        ValueBinding vb = getValueBinding("onkeydown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Setter for onmousedown
	 * @param onmousedown - new value
	 */
	 public void setOnmousedown( String  __onmousedown ){
		this._onmousedown = __onmousedown;
	 	 }


	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Getter for onmousedown
	 * @return onmousedown value from local variable or value bindings
	 */
	 public String getOnmousedown(  ){
	         if (null != this._onmousedown)
        {
            return this._onmousedown;
        	    }
        ValueBinding vb = getValueBinding("onmousedown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * selectedTab
	 * Setter for selectedTab
	 * @param selectedTab - new value
	 */
	 public void setSelectedTab( Object  __selectedTab ){
		this._selectedTab = __selectedTab;
	 	 }


	/*
	 * selectedTab
	 * Getter for selectedTab
	 * @return selectedTab value from local variable or value bindings
	 */
	 public Object getSelectedTab(  ){
	         if (null != this._selectedTab)
        {
            return this._selectedTab;
        	    }
        ValueBinding vb = getValueBinding("selectedTab");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A CSS class for content of a tab panel
	 * Setter for contentClass
	 * @param contentClass - new value
	 */
	 public void setContentClass( String  __contentClass ){
		this._contentClass = __contentClass;
	 	 }


	/*
	 * A CSS class for content of a tab panel
	 * Getter for contentClass
	 * @return contentClass value from local variable or value bindings
	 */
	 public String getContentClass(  ){
	         if (null != this._contentClass)
        {
            return this._contentClass;
        	    }
        ValueBinding vb = getValueBinding("contentClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	      	/*
	 * HTML: script expression; a pointer button is released
	 * Setter for onmouseup
	 * @param onmouseup - new value
	 */
	 public void setOnmouseup( String  __onmouseup ){
		this._onmouseup = __onmouseup;
	 	 }


	/*
	 * HTML: script expression; a pointer button is released
	 * Getter for onmouseup
	 * @return onmouseup value from local variable or value bindings
	 */
	 public String getOnmouseup(  ){
	         if (null != this._onmouseup)
        {
            return this._onmouseup;
        	    }
        ValueBinding vb = getValueBinding("onmouseup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * HTML: a script expression; a pointer is moved within
	 * Setter for onmousemove
	 * @param onmousemove - new value
	 */
	 public void setOnmousemove( String  __onmousemove ){
		this._onmousemove = __onmousemove;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved within
	 * Getter for onmousemove
	 * @return onmousemove value from local variable or value bindings
	 */
	 public String getOnmousemove(  ){
	         if (null != this._onmousemove)
        {
            return this._onmousemove;
        	    }
        ValueBinding vb = getValueBinding("onmousemove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Sets tab headers spacing. It should be a valid size unit expression
	 * Setter for headerSpacing
	 * @param headerSpacing - new value
	 */
	 public void setHeaderSpacing( String  __headerSpacing ){
		this._headerSpacing = __headerSpacing;
	 	 }


	/*
	 * Sets tab headers spacing. It should be a valid size unit expression
	 * Getter for headerSpacing
	 * @return headerSpacing value from local variable or value bindings
	 */
	 public String getHeaderSpacing(  ){
	         if (null != this._headerSpacing)
        {
            return this._headerSpacing;
        	    }
        ValueBinding vb = getValueBinding("headerSpacing");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "1px";
        }
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.TabPanel";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[28];
        values[0] = super.saveState(context);
  	 	          values[1] = _width;
	   	 	
  	 	          values[2] = _contentStyle;
	   	 	
  	 	          values[3] = _title;
	   	 	
   	 	          values[4] = _activeTabClass;
	   	 	
   	 	          values[5] = _tabClass;
	   	 	
    	 	          values[6] = _dir;
	   	 	
   	 	          values[7] = _styleClass;
	   	 	
  	 	          values[8] = _switchType;
	   	 	
  	 	          values[9] = _height;
	   	 	
  	 	          values[10] = _onkeypress;
	   	 	
  	 	          values[11] = _ondblclick;
	   	 	
  	 	          values[12] = _headerAlignment;
	   	 	
  	 	          values[13] = _style;
	   	 	
  	 	          values[14] = _onmouseover;
	   	 	
   	 	          values[15] = _onkeyup;
	   	 	
  	 	          values[16] = _disabledTabClass;
	   	 	
    	 	          values[17] = _lang;
	   	 	
   	 	          values[18] = _onclick;
	   	 	
  	 	          values[19] = _inactiveTabClass;
	   	 	
   	 	          values[20] = _onmouseout;
	   	 	
  	 	          values[21] = _onkeydown;
	   	 	
  	 	          values[22] = _onmousedown;
	   	 	
  	 	          values[23] = _selectedTab;
	   	 	
  	 	          values[24] = _contentClass;
	   	 	
     	 	          values[25] = _onmouseup;
	   	 	
   	 	          values[26] = _onmousemove;
	   	 	
  	 	          values[27] = _headerSpacing;
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	 	          _width = (String)values[1] ;
	   	 	
  	 	          _contentStyle = (String)values[2] ;
	   	 	
  	 	          _title = (String)values[3] ;
	   	 	
   	 	          _activeTabClass = (String)values[4] ;
	   	 	
   	 	          _tabClass = (String)values[5] ;
	   	 	
    	 	          _dir = (String)values[6] ;
	   	 	
   	 	          _styleClass = (String)values[7] ;
	   	 	
  	 	          _switchType = (String)values[8] ;
	   	 	
  	 	          _height = (String)values[9] ;
	   	 	
  	 	          _onkeypress = (String)values[10] ;
	   	 	
  	 	          _ondblclick = (String)values[11] ;
	   	 	
  	 	          _headerAlignment = (String)values[12] ;
	   	 	
  	 	          _style = (String)values[13] ;
	   	 	
  	 	          _onmouseover = (String)values[14] ;
	   	 	
   	 	          _onkeyup = (String)values[15] ;
	   	 	
  	 	          _disabledTabClass = (String)values[16] ;
	   	 	
    	 	          _lang = (String)values[17] ;
	   	 	
   	 	          _onclick = (String)values[18] ;
	   	 	
  	 	          _inactiveTabClass = (String)values[19] ;
	   	 	
   	 	          _onmouseout = (String)values[20] ;
	   	 	
  	 	          _onkeydown = (String)values[21] ;
	   	 	
  	 	          _onmousedown = (String)values[22] ;
	   	 	
  	 	          _selectedTab = (Object)values[23] ;
	   	 	
  	 	          _contentClass = (String)values[24] ;
	   	 	
     	 	          _onmouseup = (String)values[25] ;
	   	 	
   	 	          _onmousemove = (String)values[26] ;
	   	 	
  	 	          _headerSpacing = (String)values[27] ;
	   	 	
 	
		
	}	
// Utilites

}