/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import java.lang.Object ;
import javax.faces.el.MethodBinding ;
import org.richfaces.component.UITreeNode ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.TreeNode
 * Component-Family org.richfaces.TreeNode
  	 * Renderer-Type org.richfaces.TreeNodeRenderer
  	 * 
 */
 public class HtmlTreeNode extends org.richfaces.component.UITreeNode {

  public static final String COMPONENT_TYPE = "org.richfaces.TreeNode";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlTreeNode (){
  	  	setRendererType("org.richfaces.TreeNodeRenderer");
  	  }

// Component properties fields
 	/**
	 * dragValue
	 * Data to be sent to the drop zone after a drop event.
	 */
	 	 private Object  _dragValue = null; /* Default is null*/
	 	  	/**
	 * ondragend
	 * A JavaScript event handler called after a drag operation.
	 */
	 	 private String  _ondragend = null; /* Default is null*/
	 	  	/**
	 * ajaxSubmitSelection
	 * An algorithm of AJAX request submission. "inherit", "true", "false" values are possible
	 */
	 	 private String  _ajaxSubmitSelection = null; /* Default is "inherit"*/
	 	  	/**
	 * ondragenter
	 * A JavaScript event handler called on enter draggable object to zone.
	 */
	 	 private String  _ondragenter = null; /* Default is null*/
	 	  	/**
	 * iconExpanded
	 * The icon for expanded node
	 */
	 	 private String  _iconExpanded = null; /* Default is null*/
	 	   	/**
	 * reRender
	 * Id[s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Ids, or EL Expression  with array or Collection
	 */
	 	 private Object  _reRender = null; /* Default is null*/
	 	   	/**
	 * iconCollapsed
	 * The icon for collapsed node
	 */
	 	 private String  _iconCollapsed = null; /* Default is null*/
	 	  	/**
	 * ondropend
	 * A Javascript handler for event fired on a drop even the drop for a given type is not available
	 */
	 	 private String  _ondropend = null; /* Default is null*/
	 	  	/**
	 * icon
	 * The icon for node
	 */
	 	 private String  _icon = null; /* Default is null*/
	 	  	/**
	 * selectedClass
	 * Corresponds to the HTML class attribute. Applied to selected node
	 */
	 	 private String  _selectedClass = null; /* Default is null*/
	 	  	/**
	 * ondrop
	 * It's an event that is called when something is dropped on a drop zone
	 */
	 	 private String  _ondrop = null; /* Default is null*/
	 	  	/**
	 * dragIndicator
	 * Id of the dragIndicator component used as drag operation cursor.
	 */
	 	 private String  _dragIndicator = null; /* Default is null*/
	 	  	/**
	 * changeExpandListener
	 * changeExpandListener
	 */
	 	 private MethodBinding  _changeExpandListener = null; /* Default is null*/
	 	    	/**
	 * dragListener
	 * dragListener
	 */
	 	 private MethodBinding  _dragListener = null; /* Default is null*/
	 	  	/**
	 * nodeSelectListener
	 * nodeSelectListener
	 */
	 	 private MethodBinding  _nodeSelectListener = null; /* Default is null*/
	 	   	/**
	 * type
	 * A node type.
	 */
	 	 private String  _type = null; /* Default is null*/
	 	  	/**
	 * dropValue
	 * Data to be processed after a drop event.
	 */
	 	 private Object  _dropValue = null; /* Default is null*/
	 	  	/**
	 * dropListener
	 * dropListener
	 */
	 	 private MethodBinding  _dropListener = null; /* Default is null*/
	 	   	/**
	 * highlightedClass
	 * Corresponds to the HTML class attribute. Applied to highlighted node
	 */
	 	 private String  _highlightedClass = null; /* Default is null*/
	 	   	/**
	 * iconLeaf
	 * iconLeaf
	 */
	 	 private String  _iconLeaf = null; /* Default is null*/
	 	  	/**
	 * ondragexit
	 * A JavaScript event handler called after a drag object leaves zone.
	 */
	 	 private String  _ondragexit = null; /* Default is null*/
	 	  	/**
	 * nodeClass
	 * Name of node CSS class
	 */
	 	 private String  _nodeClass = null; /* Default is ""*/
	 	  	/**
	 * ondragstart
	 * A JavaScript event handler called before drag object.
	 */
	 	 private String  _ondragstart = null; /* Default is null*/
	 	  	/**
	 * oncontextmenu
	 * JavaScript handler to be called on right click.
		   Returning false prevents default browser context menu from being displayed
	 */
	 	 private String  _oncontextmenu = null; /* Default is null*/
	 	   	/**
	 * typeMapping
	 * Map between a draggable type and an indicator name on zone. it's defined with the pair (drag type:indicator name))
	 */
	 	 private Object  _typeMapping = null; /* Default is null*/
	 	  
// Getters-setters
 	/*
	 * Data to be sent to the drop zone after a drop event.
	 * Setter for dragValue
	 * @param dragValue - new value
	 */
	 public void setDragValue( Object  __dragValue ){
		this._dragValue = __dragValue;
	 	 }


	/*
	 * Data to be sent to the drop zone after a drop event.
	 * Getter for dragValue
	 * @return dragValue value from local variable or value bindings
	 */
	 public Object getDragValue(  ){
	         if (null != this._dragValue)
        {
            return this._dragValue;
        	    }
        ValueBinding vb = getValueBinding("dragValue");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A JavaScript event handler called after a drag operation.
	 * Setter for ondragend
	 * @param ondragend - new value
	 */
	 public void setOndragend( String  __ondragend ){
		this._ondragend = __ondragend;
	 	 }


	/*
	 * A JavaScript event handler called after a drag operation.
	 * Getter for ondragend
	 * @return ondragend value from local variable or value bindings
	 */
	 public String getOndragend(  ){
	         if (null != this._ondragend)
        {
            return this._ondragend;
        	    }
        ValueBinding vb = getValueBinding("ondragend");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * An algorithm of AJAX request submission. "inherit", "true", "false" values are possible
	 * Setter for ajaxSubmitSelection
	 * @param ajaxSubmitSelection - new value
	 */
	 public void setAjaxSubmitSelection( String  __ajaxSubmitSelection ){
		this._ajaxSubmitSelection = __ajaxSubmitSelection;
	 	 }


	/*
	 * An algorithm of AJAX request submission. "inherit", "true", "false" values are possible
	 * Getter for ajaxSubmitSelection
	 * @return ajaxSubmitSelection value from local variable or value bindings
	 */
	 public String getAjaxSubmitSelection(  ){
	         if (null != this._ajaxSubmitSelection)
        {
            return this._ajaxSubmitSelection;
        	    }
        ValueBinding vb = getValueBinding("ajaxSubmitSelection");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "inherit";
        }
	 	 }
	   	/*
	 * A JavaScript event handler called on enter draggable object to zone.
	 * Setter for ondragenter
	 * @param ondragenter - new value
	 */
	 public void setOndragenter( String  __ondragenter ){
		this._ondragenter = __ondragenter;
	 	 }


	/*
	 * A JavaScript event handler called on enter draggable object to zone.
	 * Getter for ondragenter
	 * @return ondragenter value from local variable or value bindings
	 */
	 public String getOndragenter(  ){
	         if (null != this._ondragenter)
        {
            return this._ondragenter;
        	    }
        ValueBinding vb = getValueBinding("ondragenter");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The icon for expanded node
	 * Setter for iconExpanded
	 * @param iconExpanded - new value
	 */
	 public void setIconExpanded( String  __iconExpanded ){
		this._iconExpanded = __iconExpanded;
	 	 }


	/*
	 * The icon for expanded node
	 * Getter for iconExpanded
	 * @return iconExpanded value from local variable or value bindings
	 */
	 public String getIconExpanded(  ){
	         if (null != this._iconExpanded)
        {
            return this._iconExpanded;
        	    }
        ValueBinding vb = getValueBinding("iconExpanded");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Id[s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Ids, or EL Expression  with array or Collection
	 * Setter for reRender
	 * @param reRender - new value
	 */
	 public void setReRender( Object  __reRender ){
		this._reRender = __reRender;
	 	 }


	/*
	 * Id[s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Ids, or EL Expression  with array or Collection
	 * Getter for reRender
	 * @return reRender value from local variable or value bindings
	 */
	 public Object getReRender(  ){
	         if (null != this._reRender)
        {
            return this._reRender;
        	    }
        ValueBinding vb = getValueBinding("reRender");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * The icon for collapsed node
	 * Setter for iconCollapsed
	 * @param iconCollapsed - new value
	 */
	 public void setIconCollapsed( String  __iconCollapsed ){
		this._iconCollapsed = __iconCollapsed;
	 	 }


	/*
	 * The icon for collapsed node
	 * Getter for iconCollapsed
	 * @return iconCollapsed value from local variable or value bindings
	 */
	 public String getIconCollapsed(  ){
	         if (null != this._iconCollapsed)
        {
            return this._iconCollapsed;
        	    }
        ValueBinding vb = getValueBinding("iconCollapsed");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A Javascript handler for event fired on a drop even the drop for a given type is not available
	 * Setter for ondropend
	 * @param ondropend - new value
	 */
	 public void setOndropend( String  __ondropend ){
		this._ondropend = __ondropend;
	 	 }


	/*
	 * A Javascript handler for event fired on a drop even the drop for a given type is not available
	 * Getter for ondropend
	 * @return ondropend value from local variable or value bindings
	 */
	 public String getOndropend(  ){
	         if (null != this._ondropend)
        {
            return this._ondropend;
        	    }
        ValueBinding vb = getValueBinding("ondropend");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The icon for node
	 * Setter for icon
	 * @param icon - new value
	 */
	 public void setIcon( String  __icon ){
		this._icon = __icon;
	 	 }


	/*
	 * The icon for node
	 * Getter for icon
	 * @return icon value from local variable or value bindings
	 */
	 public String getIcon(  ){
	         if (null != this._icon)
        {
            return this._icon;
        	    }
        ValueBinding vb = getValueBinding("icon");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute. Applied to selected node
	 * Setter for selectedClass
	 * @param selectedClass - new value
	 */
	 public void setSelectedClass( String  __selectedClass ){
		this._selectedClass = __selectedClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute. Applied to selected node
	 * Getter for selectedClass
	 * @return selectedClass value from local variable or value bindings
	 */
	 public String getSelectedClass(  ){
	         if (null != this._selectedClass)
        {
            return this._selectedClass;
        	    }
        ValueBinding vb = getValueBinding("selectedClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * It's an event that is called when something is dropped on a drop zone
	 * Setter for ondrop
	 * @param ondrop - new value
	 */
	 public void setOndrop( String  __ondrop ){
		this._ondrop = __ondrop;
	 	 }


	/*
	 * It's an event that is called when something is dropped on a drop zone
	 * Getter for ondrop
	 * @return ondrop value from local variable or value bindings
	 */
	 public String getOndrop(  ){
	         if (null != this._ondrop)
        {
            return this._ondrop;
        	    }
        ValueBinding vb = getValueBinding("ondrop");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Id of the dragIndicator component used as drag operation cursor.
	 * Setter for dragIndicator
	 * @param dragIndicator - new value
	 */
	 public void setDragIndicator( String  __dragIndicator ){
		this._dragIndicator = __dragIndicator;
	 	 }


	/*
	 * Id of the dragIndicator component used as drag operation cursor.
	 * Getter for dragIndicator
	 * @return dragIndicator value from local variable or value bindings
	 */
	 public String getDragIndicator(  ){
	         if (null != this._dragIndicator)
        {
            return this._dragIndicator;
        	    }
        ValueBinding vb = getValueBinding("dragIndicator");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * changeExpandListener
	 * Setter for changeExpandListener
	 * @param changeExpandListener - new value
	 */
	 public void setChangeExpandListener( MethodBinding  __changeExpandListener ){
		this._changeExpandListener = __changeExpandListener;
	 	 }


	/*
	 * changeExpandListener
	 * Getter for changeExpandListener
	 * @return changeExpandListener value from local variable or value bindings
	 */
	 public MethodBinding getChangeExpandListener(  ){
	         if (null != this._changeExpandListener)
        {
            return this._changeExpandListener;
                } else {
            return null;
        }
	 	 }
	     	/*
	 * dragListener
	 * Setter for dragListener
	 * @param dragListener - new value
	 */
	 public void setDragListener( MethodBinding  __dragListener ){
		this._dragListener = __dragListener;
	 	 }


	/*
	 * dragListener
	 * Getter for dragListener
	 * @return dragListener value from local variable or value bindings
	 */
	 public MethodBinding getDragListener(  ){
	         if (null != this._dragListener)
        {
            return this._dragListener;
                } else {
            return null;
        }
	 	 }
	   	/*
	 * nodeSelectListener
	 * Setter for nodeSelectListener
	 * @param nodeSelectListener - new value
	 */
	 public void setNodeSelectListener( MethodBinding  __nodeSelectListener ){
		this._nodeSelectListener = __nodeSelectListener;
	 	 }


	/*
	 * nodeSelectListener
	 * Getter for nodeSelectListener
	 * @return nodeSelectListener value from local variable or value bindings
	 */
	 public MethodBinding getNodeSelectListener(  ){
	         if (null != this._nodeSelectListener)
        {
            return this._nodeSelectListener;
                } else {
            return null;
        }
	 	 }
	    	/*
	 * A node type.
	 * Setter for type
	 * @param type - new value
	 */
	 public void setType( String  __type ){
		this._type = __type;
	 	 }


	/*
	 * A node type.
	 * Getter for type
	 * @return type value from local variable or value bindings
	 */
	 public String getType(  ){
	         if (null != this._type)
        {
            return this._type;
        	    }
        ValueBinding vb = getValueBinding("type");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Data to be processed after a drop event.
	 * Setter for dropValue
	 * @param dropValue - new value
	 */
	 public void setDropValue( Object  __dropValue ){
		this._dropValue = __dropValue;
	 	 }


	/*
	 * Data to be processed after a drop event.
	 * Getter for dropValue
	 * @return dropValue value from local variable or value bindings
	 */
	 public Object getDropValue(  ){
	         if (null != this._dropValue)
        {
            return this._dropValue;
        	    }
        ValueBinding vb = getValueBinding("dropValue");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * dropListener
	 * Setter for dropListener
	 * @param dropListener - new value
	 */
	 public void setDropListener( MethodBinding  __dropListener ){
		this._dropListener = __dropListener;
	 	 }


	/*
	 * dropListener
	 * Getter for dropListener
	 * @return dropListener value from local variable or value bindings
	 */
	 public MethodBinding getDropListener(  ){
	         if (null != this._dropListener)
        {
            return this._dropListener;
                } else {
            return null;
        }
	 	 }
	    	/*
	 * Corresponds to the HTML class attribute. Applied to highlighted node
	 * Setter for highlightedClass
	 * @param highlightedClass - new value
	 */
	 public void setHighlightedClass( String  __highlightedClass ){
		this._highlightedClass = __highlightedClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute. Applied to highlighted node
	 * Getter for highlightedClass
	 * @return highlightedClass value from local variable or value bindings
	 */
	 public String getHighlightedClass(  ){
	         if (null != this._highlightedClass)
        {
            return this._highlightedClass;
        	    }
        ValueBinding vb = getValueBinding("highlightedClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * iconLeaf
	 * Setter for iconLeaf
	 * @param iconLeaf - new value
	 */
	 public void setIconLeaf( String  __iconLeaf ){
		this._iconLeaf = __iconLeaf;
	 	 }


	/*
	 * iconLeaf
	 * Getter for iconLeaf
	 * @return iconLeaf value from local variable or value bindings
	 */
	 public String getIconLeaf(  ){
	         if (null != this._iconLeaf)
        {
            return this._iconLeaf;
        	    }
        ValueBinding vb = getValueBinding("iconLeaf");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A JavaScript event handler called after a drag object leaves zone.
	 * Setter for ondragexit
	 * @param ondragexit - new value
	 */
	 public void setOndragexit( String  __ondragexit ){
		this._ondragexit = __ondragexit;
	 	 }


	/*
	 * A JavaScript event handler called after a drag object leaves zone.
	 * Getter for ondragexit
	 * @return ondragexit value from local variable or value bindings
	 */
	 public String getOndragexit(  ){
	         if (null != this._ondragexit)
        {
            return this._ondragexit;
        	    }
        ValueBinding vb = getValueBinding("ondragexit");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Name of node CSS class
	 * Setter for nodeClass
	 * @param nodeClass - new value
	 */
	 public void setNodeClass( String  __nodeClass ){
		this._nodeClass = __nodeClass;
	 	 }


	/*
	 * Name of node CSS class
	 * Getter for nodeClass
	 * @return nodeClass value from local variable or value bindings
	 */
	 public String getNodeClass(  ){
	         if (null != this._nodeClass)
        {
            return this._nodeClass;
        	    }
        ValueBinding vb = getValueBinding("nodeClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * A JavaScript event handler called before drag object.
	 * Setter for ondragstart
	 * @param ondragstart - new value
	 */
	 public void setOndragstart( String  __ondragstart ){
		this._ondragstart = __ondragstart;
	 	 }


	/*
	 * A JavaScript event handler called before drag object.
	 * Getter for ondragstart
	 * @return ondragstart value from local variable or value bindings
	 */
	 public String getOndragstart(  ){
	         if (null != this._ondragstart)
        {
            return this._ondragstart;
        	    }
        ValueBinding vb = getValueBinding("ondragstart");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript handler to be called on right click.
		   Returning false prevents default browser context menu from being displayed
	 * Setter for oncontextmenu
	 * @param oncontextmenu - new value
	 */
	 public void setOncontextmenu( String  __oncontextmenu ){
		this._oncontextmenu = __oncontextmenu;
	 	 }


	/*
	 * JavaScript handler to be called on right click.
		   Returning false prevents default browser context menu from being displayed
	 * Getter for oncontextmenu
	 * @return oncontextmenu value from local variable or value bindings
	 */
	 public String getOncontextmenu(  ){
	         if (null != this._oncontextmenu)
        {
            return this._oncontextmenu;
        	    }
        ValueBinding vb = getValueBinding("oncontextmenu");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Map between a draggable type and an indicator name on zone. it's defined with the pair (drag type:indicator name))
	 * Setter for typeMapping
	 * @param typeMapping - new value
	 */
	 public void setTypeMapping( Object  __typeMapping ){
		this._typeMapping = __typeMapping;
	 	 }


	/*
	 * Map between a draggable type and an indicator name on zone. it's defined with the pair (drag type:indicator name))
	 * Getter for typeMapping
	 * @return typeMapping value from local variable or value bindings
	 */
	 public Object getTypeMapping(  ){
	         if (null != this._typeMapping)
        {
            return this._typeMapping;
        	    }
        ValueBinding vb = getValueBinding("typeMapping");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.TreeNode";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[26];
        values[0] = super.saveState(context);
 	 	          values[1] = _dragValue;
	   	 	
  	 	          values[2] = _ondragend;
	   	 	
  	 	          values[3] = _ajaxSubmitSelection;
	   	 	
  	 	          values[4] = _ondragenter;
	   	 	
  	 	          values[5] = _iconExpanded;
	   	 	
   	 	          values[6] = _reRender;
	   	 	
   	 	          values[7] = _iconCollapsed;
	   	 	
  	 	          values[8] = _ondropend;
	   	 	
  	 	          values[9] = _icon;
	   	 	
  	 	          values[10] = _selectedClass;
	   	 	
  	 	          values[11] = _ondrop;
	   	 	
  	 	          values[12] = _dragIndicator;
	   	 	
  	 	          values[13] = saveAttachedState(context, _changeExpandListener );		
	   	 	
    	 	          values[14] = saveAttachedState(context, _dragListener );		
	   	 	
  	 	          values[15] = saveAttachedState(context, _nodeSelectListener );		
	   	 	
   	 	          values[16] = _type;
	   	 	
  	 	          values[17] = _dropValue;
	   	 	
  	 	          values[18] = saveAttachedState(context, _dropListener );		
	   	 	
   	 	          values[19] = _highlightedClass;
	   	 	
   	 	          values[20] = _iconLeaf;
	   	 	
  	 	          values[21] = _ondragexit;
	   	 	
  	 	          values[22] = _nodeClass;
	   	 	
  	 	          values[23] = _ondragstart;
	   	 	
  	 	          values[24] = _oncontextmenu;
	   	 	
   	 	          values[25] = _typeMapping;
	   	 	
  	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
 	 	          _dragValue = (Object)values[1] ;
	   	 	
  	 	          _ondragend = (String)values[2] ;
	   	 	
  	 	          _ajaxSubmitSelection = (String)values[3] ;
	   	 	
  	 	          _ondragenter = (String)values[4] ;
	   	 	
  	 	          _iconExpanded = (String)values[5] ;
	   	 	
   	 	          _reRender = (Object)values[6] ;
	   	 	
   	 	          _iconCollapsed = (String)values[7] ;
	   	 	
  	 	          _ondropend = (String)values[8] ;
	   	 	
  	 	          _icon = (String)values[9] ;
	   	 	
  	 	          _selectedClass = (String)values[10] ;
	   	 	
  	 	          _ondrop = (String)values[11] ;
	   	 	
  	 	          _dragIndicator = (String)values[12] ;
	   	 	
  	 	          _changeExpandListener = (MethodBinding)restoreAttachedState(context,values[13] );		
	   	 	
    	 	          _dragListener = (MethodBinding)restoreAttachedState(context,values[14] );		
	   	 	
  	 	          _nodeSelectListener = (MethodBinding)restoreAttachedState(context,values[15] );		
	   	 	
   	 	          _type = (String)values[16] ;
	   	 	
  	 	          _dropValue = (Object)values[17] ;
	   	 	
  	 	          _dropListener = (MethodBinding)restoreAttachedState(context,values[18] );		
	   	 	
   	 	          _highlightedClass = (String)values[19] ;
	   	 	
   	 	          _iconLeaf = (String)values[20] ;
	   	 	
  	 	          _ondragexit = (String)values[21] ;
	   	 	
  	 	          _nodeClass = (String)values[22] ;
	   	 	
  	 	          _ondragstart = (String)values[23] ;
	   	 	
  	 	          _oncontextmenu = (String)values[24] ;
	   	 	
   	 	          _typeMapping = (Object)values[25] ;
	   	 	
  	
		
	}	
// Utilites

}