/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.event;

import javax.faces.component.StateHolder;
import javax.faces.component.UIComponentBase;
import javax.faces.el.MethodBinding;
import javax.faces.context.FacesContext;


public class DataScrollerAdapter implements DataScrollerListener, StateHolder {

    public static Class[] SIGNATURE = new Class[] { DataScrollerEvent.class };

    private MethodBinding scrollerMethod;
    private boolean scrolerTransient;

    /**
    * empty constructor needed.
    *
    */
    public DataScrollerAdapter() {
    }

   
    public DataScrollerAdapter(MethodBinding myScrollerMethod) {
    	scrollerMethod = myScrollerMethod;
    }

    /**
    * Processes a SliderEvent.
    *
    * @param event  the slider event
    */
    public void processScroller(DataScrollerEvent event) { 
    	FacesContext context = FacesContext.getCurrentInstance();
    	if (scrollerMethod!=null){
          scrollerMethod.invoke(context, new Object[]{event});
    	}
    }

    /**
    * Saves the internal state of this DataFilterSliderAdapter.
    *
    * @param context  the Faces context
    *
    * @return  the saved state
    */
    public Object saveState(FacesContext context) {
        return UIComponentBase.saveAttachedState(context, scrollerMethod);
    }

    /**
    * Restores the internal state of this DataFilterSliderAdapter.
    *
    * @param context  the Faces context
    * @param object   the state to restore
    */
    public void restoreState(FacesContext context, Object object){
    	scrollerMethod = (MethodBinding) UIComponentBase.restoreAttachedState(context, object);
    }

    /**
    * Returns true if this DataFilterSliderAdapter is transient and should
    * not be state saved, otherwise false.
    *
    * @return  the value of transient
    */
    public boolean isTransient() {
        return scrolerTransient;
    }

    /**
    * Indicates whether or not this DataFilterSliderAdapter is transient and should
    * not be state saved.
    *
    * @param isTransient  the new value for transient
    */
    public void setTransient(

    boolean isTransient) {
    	scrolerTransient = isTransient;
    }

}
