/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.renderkit;

import java.io.IOException;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import javax.faces.FacesException;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;
import javax.faces.render.Renderer;

import org.ajax4jsf.framework.renderer.HeaderResourcesRendererBase;
import org.richfaces.component.UIDragIndicator;
import org.richfaces.org.apache.commons.lang.StringEscapeUtils;

/**
 * Base renderer class for drag indicator ( marker ).
 * @author shura
 *
 */
public class DragIndicatorRendererBase extends HeaderResourcesRendererBase {
	public static final String ACCEPT_CLASS_ATTR = "ils:acceptclass";
	public static final String REJECT_CLASS_ATTR = "ils:rejectclass";
	public static final String ACCEPT_CLASS = "acceptClass";
	public static final String REJECT_CLASS = "rejectClass";
	public static final String RENDERER_TYPE = "com.exadel.jsf.renderer.DropIndicatorRenderer";

	public static final String ACCEPT = "accept";
	public static final String DEFAULT = "default";
	public static final String REJECT = "reject";

	protected static final Collection MARKERS_PREDEFINED = new ArrayList(3);
	static {
		MARKERS_PREDEFINED.add(ACCEPT);
		MARKERS_PREDEFINED.add(DEFAULT);
		MARKERS_PREDEFINED.add(REJECT);
	}
	
	public static final String SINGLE = "single";
	public static final String MULTI = "multi";

	protected static final Collection FACETS_PREDEFINED = new ArrayList(2);
	static {
		FACETS_PREDEFINED.add(SINGLE);
		FACETS_PREDEFINED.add(MULTI);
	}

	private Renderer dragIndicatorViewRenderer;

	public DragIndicatorRendererBase() {
		super();

		try {
			dragIndicatorViewRenderer = (Renderer) Class.forName("org.richfaces.renderkit.html.DragIndicatorViewRenderer").newInstance();
		} catch (InstantiationException e) {
			throw new FacesException(e);
		} catch (IllegalAccessException e) {
			throw new FacesException(e);
		} catch (ClassNotFoundException e) {
			throw new FacesException(e);
		}
	}

	/* (non-Javadoc)
	 * @see org.ajax4jsf.framework.renderer.RendererBase#getComponentClass()
	 */
	protected Class getComponentClass() {
		return UIDragIndicator.class;
	}

	public void encodeChildren(FacesContext context, UIComponent component) throws IOException {
	}

//	public String encodeChild(FacesContext context, Object object) throws IOException {
//		ResponseWriter responseWriter = context.getResponseWriter();
//		StringWriter dumpWriter = new StringWriter();
//
//		try {
//			UIComponent component = (UIComponent) object;
//
//			context.setResponseWriter(responseWriter.cloneWithWriter(dumpWriter));
//
//			renderChild(context, component);
//
//			context.getResponseWriter().flush();
//		} finally {
//			context.setResponseWriter(responseWriter);
//		}
//
//		return TemplateUtil.replaceParams(dumpWriter.getBuffer().toString(), "jsParams");
//	}

	public boolean getRendersChildren() {
		return true;
	}

	protected boolean notHasFacet(UIComponent component, Object facetName) {
		return component.getFacet((String) facetName) == null;
	}

	protected String getPredefinedMarker(FacesContext context, Object facetName) {
		if (MARKERS_PREDEFINED.contains(facetName)) {
			return StringEscapeUtils.escapeJavaScript("<img alt=\"\" border=\"0\" width=\"16\" height=\"16\" src=\""  + 
					getResource("/org/richfaces/renderkit/html/images/" + facetName + ".gif").getUri(context, null) +"\" />");
		}

		throw new IllegalArgumentException("No predefined marker with [" + facetName + "] name exists!");
	}

	public void encodeChildScripts(FacesContext context, UIComponent component)
	throws IOException {
		ResponseWriter responseWriter = context.getResponseWriter();

		for (Iterator iterator = MARKERS_PREDEFINED.iterator(); iterator.hasNext();) {
			String markerName = (String) iterator.next();
			
			responseWriter.write("elt.markers['" + markerName + "'] = \"");
			responseWriter.write(getPredefinedMarker(context, markerName));
			responseWriter.write("\";\n");
		} 
		
		for (Iterator iterator = FACETS_PREDEFINED.iterator(); iterator.hasNext();) {
			String facetName = (String) iterator.next();

			UIComponent facet = component.getFacet(facetName);

			StringWriter dumpWriter = new StringWriter();
			
			try {
				context.setResponseWriter(responseWriter.cloneWithWriter(dumpWriter));

				if (facet != null && facet.isRendered()) {
					renderChild(context, facet);
				} else {

					dragIndicatorViewRenderer.encodeBegin(context, component);
					dragIndicatorViewRenderer.encodeEnd(context, component);

					context.getResponseWriter().flush();
				}
			} finally {
				context.setResponseWriter(responseWriter);
			}

			responseWriter.write("elt.indicatorTemplates['" + facetName + "'] = function(element, jsParams) {\n");
			responseWriter.write("var content = ");
			String result = TemplateUtil.replaceParams(dumpWriter.getBuffer().toString(), "jsParams");
			responseWriter.write(result + ";\n new Insertion.Top(element, content);\n");
			responseWriter.write("};");
		}
	}
}
