/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.renderkit;

import java.io.IOException;
import java.util.Map;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;

import org.ajax4jsf.framework.renderer.AjaxRendererUtils;
import org.ajax4jsf.framework.renderer.RendererUtils.HTML;
import org.ajax4jsf.framework.util.HtmlDimensions;
import org.ajax4jsf.framework.util.javascript.JSFunction;
import org.richfaces.component.UISwitchablePanel;
import org.richfaces.component.UITab;
import org.richfaces.component.UITabPanel;
import org.richfaces.component.util.HtmlUtil;


/**
 * @author Nick Belaevski - nbelaevski@exadel.com
 * created 12.01.2007
 * 
 */
public class TabHeaderRendererBase extends org.ajax4jsf.framework.renderer.HeaderResourcesRendererBase {

	private static final String LABEL_SUFFIX = "_lbl";
	
	protected Class getComponentClass() {
		return UITab.class;
	}

	public void encodeTabLabel(FacesContext context, UITab tab) throws IOException{
		ResponseWriter writer = context.getResponseWriter();

		boolean disabled = tab.isDisabled();
		UITabPanel pane = tab.getPane();
		String method = tab.getSwitchType();
		boolean ajax = UISwitchablePanel.AJAX_METHOD.equals(method);
		boolean clientSide = UISwitchablePanel.CLIENT_METHOD.equals(method);
		String label = tab.getLabel();

		if (label == null) {
			label = "";
		}

		String clientId = tab.getClientId(context) ;

		String style = (String) tab.getAttributes().get("style");

		if (!disabled) {
			if(clientSide) {
				writer.writeAttribute(HTML.onclick_ATTRIBUTE,"RichFaces.switchTab('"+pane.getClientId(context)+"','"+clientId+"','"+getUtils().formatValue(context, pane, tab.getName())+"');","switchScript");
			} else {
				String activeCheck = "if (RichFaces.isTabActive('" + clientId + LABEL_SUFFIX + "')) return false;";

				if(ajax) {
					JSFunction function = AjaxRendererUtils.buildAjaxFunction(tab,
							context);
					Map eventOptions = AjaxRendererUtils.buildEventOptions(context,
							tab);
					function.addParameter(eventOptions);

					StringBuffer buffer = new StringBuffer();
					function.appendScript(buffer);
					buffer.append("; return false; this.onclick = null;");
					String script = buffer.toString();
					writer.writeAttribute(HTML.onclick_ATTRIBUTE, activeCheck + script, null);
				} else {
					StringBuffer script = new StringBuffer("var _formName = A4J.findForm(this).id; var _paramName = '" + clientId + "_server_submit'; var _params = new Object(); _params[_paramName] = _paramName; _JSFFormSubmit('");
					script.append(clientId);
					script.append("', _formName, null, _params);");
					script.append("this.onclick = null; _clearJSFFormParameters(_formName, null, [_paramName]);");

					writer.writeAttribute(HTML.onclick_ATTRIBUTE, activeCheck + script.toString()
							/* "RichFaces.submitTab(this,'"+clientId + "_inp" +"','"+pane.getClientId(context)+"');"*/, null);				
				}
			}
		}


		String width = tab.getLabelWidth();

		if (width != null) {
			style += ";width: " + getUtils().encodePctOrPx(width) + ";";
		}

		if (style != null){
			writer.writeAttribute(HTML.style_ATTRIBUTE, style, "tabStyle");
		}
	}

	public boolean getRendersChildren() {
		return true;
	}

	public void encodeCellClasses(FacesContext context, UITab tab) throws IOException {
		ResponseWriter writer = context.getResponseWriter();
		String labelClass;
		if (tab.isDisabled()) {
			labelClass = TabPanelRendererBase.DISABLED_CELL_CLASSES;
		} else {
			if (tab.isActive()) {
				labelClass = TabPanelRendererBase.ACTIVE_CELL_CLASSES;
			} else {
				labelClass = TabPanelRendererBase.INACTIVE_CELL_CLASSES;
			}
		}

		writer.writeAttribute(HTML.class_ATTRIBUTE, labelClass, null);
	}

	/**
	 * Hook method for create AJAX command script, in non-ajax state -simple write script attributes
	 * @param writer 
	 * @param context
	 * @param component
	 * @throws IOException 
	 */
	protected void writeTabElementScript(ResponseWriter writer, FacesContext context, UIComponent component) throws IOException {
		getUtils().encodeAttribute(context,component,HTML.onclick_ATTRIBUTE);
		getUtils().encodeAttribute(context,component,HTML.ondblclick_ATTRIBUTE);
		getUtils().encodeAttribute(context,component,HTML.onkeydown_ATTRIBUTE);
		getUtils().encodeAttribute(context,component,HTML.onkeyup_ATTRIBUTE);
		getUtils().encodeAttribute(context,component,HTML.onkeypress_ATTRIBUTE);
	}

	public void writeLabel(FacesContext context, UITab tab) throws IOException{
		ResponseWriter writer = context.getResponseWriter();

		String labelClass = "";
		if (tab.isDisabled()) {
			labelClass = TabPanelRendererBase.getDisabledTabClass(tab);
		} else {
			if (tab.isActive()) {
				labelClass = TabPanelRendererBase.getActiveTabClass(tab);
			} else {
				labelClass = TabPanelRendererBase.getInactiveTabClass(tab);
			}

			writer.writeAttribute(HTML.onmouseover_ATTRIBUTE, ONMOUSEOVER, "tabOnMouseOver");
			writer.writeAttribute(HTML.onmouseout_ATTRIBUTE, ONMOUSEOUT, "tabOnMouseOut");
		}
		writer.writeAttribute(HTML.class_ATTRIBUTE, labelClass, "tabClass");
		String title = tab.getTitle();
		if (title != null && title.length()!=0) {
			writer.writeAttribute(HTML.title_ATTRIBUTE, title, null);
		}

		String label = tab.getLabel();

		if (label == null || label.length()==0) {
			label = "&#160;";
		}

		context.getResponseWriter().write(label);
	}

	protected String encodeTabLabelWidth(FacesContext context, UITab tab) {
		String labelWidth = tab.getLabelWidth();
		if (labelWidth == null || labelWidth.trim().length() == 0) {
			return "";
		}

		return "width: " + HtmlUtil.qualifySize(labelWidth) + ";";
	}

	public String encodeHeaderSpacing(FacesContext context, UITab tab) throws IOException {
		UITabPanel pane = tab.getPane();
		String headerSpacing = pane.getHeaderSpacing();
		Double decoded = HtmlDimensions.decode(headerSpacing);
		if (decoded.doubleValue() != 0) {
			return "width: " + HtmlUtil.qualifySize(headerSpacing);
		} else {
			return "";
		}
	}

	private static final String ONMOUSEOVER = "RichFaces.overTab(this);";
	private static final String ONMOUSEOUT = "RichFaces.outTab(this);";

}
