/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.renderkit.html;

import java.io.IOException;
import java.util.Map;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;
import org.ajax4jsf.framework.renderer.AjaxRendererUtils;
import org.richfaces.component.UIDatascroller;
import org.ajax4jsf.framework.renderer.HeaderResourcesRendererBase;
import org.ajax4jsf.framework.util.javascript.JSFunction;
import org.richfaces.event.DataScrollerEvent;




public class DataScrollerRenderer extends HeaderResourcesRendererBase {	
	
	protected Class getComponentClass() {
		return UIDatascroller.class;
	}


	//public static final String RENDERER_TYPE = Datascroller.RENDERER_TYPE;

	private static final String PARAM_SUFFIX = "_parameter";

	public void decode(FacesContext context, UIComponent component) {

		String param = (String) getParamMap(context).get(
				component.getClientId(context) + PARAM_SUFFIX);

		if (param != null) {
			UIDatascroller scroller = (UIDatascroller) component;
			scroller.setPage(param);
			scroller.getPageIndex();
			String oldScrolVal = scroller.getHandleValue();        
	        String newScrolVal = Integer.toString(scroller.getPageIndex());
	        if (!newScrolVal.equals(oldScrolVal)) {

	          scroller.setHandleValue(newScrolVal);
	          DataScrollerEvent event = new DataScrollerEvent(scroller, oldScrolVal, newScrolVal);
	          event.queue();

	          AjaxRendererUtils.addRegionByName(context, component, component.getId());			
			  AjaxRendererUtils.addRegionByName(context, component, scroller.getFor());
	        }
			
			
		}
		
		
		
		
		
		
		

	}


	public void  renderPager(FacesContext context, UIComponent component) throws IOException{
		ResponseWriter out = context.getResponseWriter();
		UIDatascroller scroller=(UIDatascroller)component;
		int currentPage = scroller.getPageIndex();

		int maxPages = scroller.getMaxPages();
		if (maxPages <= 1) {
			maxPages = 2;
		}
		int pageCount = scroller.getPageCount();
		if (pageCount <= 1) {
			return;
		}
		int pageIndex = scroller.getPageIndex();
		int delta = maxPages / 2;

		int pages;
		int start;
		if (pageCount > maxPages && pageIndex > delta) {
			pages = maxPages;
			start = pageIndex - pages / 2 - 1;
			if (start + pages > pageCount) {
				start = pageCount - pages;
			}
		}
		else {
			pages = pageCount < maxPages ? pageCount : maxPages;
			start = 0;
		}

		for (int i = start, size = start + pages, j = 1; i < size; i++, j++) {
			//String styleClass;
			//String style;

			boolean isCurrentPage = (i + 1 == currentPage);
			/*
			if (isCurrentPage) {
				styleClass = scroller.getSelectedStyleClass();				
				style = scroller.getSelectedStyle();
			}
			else {
				styleClass = scroller.getStyleClass();								
				style = scroller.getStyle();				
			}
			 
		    if (style==null){
		    	style="";
		    }
		    if (styleClass==null){
		    	styleClass="";
		    }
			*/
			
			out.startElement("td", component);
			if (isCurrentPage){
			  out.writeAttribute("align", "center", null);
			  out.writeAttribute("class", "dr-dscr-act rich-datascr-act "+scroller.getStyleClass(), null);
			  out.writeAttribute("style", ""+scroller.getSelectedStyle(), null);
			}  
			else{
			  out.writeAttribute("align", "center", null);				
			  out.writeAttribute("class", "dr-dscr-inact rich-datascr-inact "+scroller.getStyleClass(), null);
			  out.writeAttribute("style", ""+scroller.getStyle(), null);						  
			  out.writeAttribute("onclick", getOnClick(context, component,Integer.toString(j)) , null);
			}
			out.writeText(Integer.toString(i + 1), null);  
			//renderChild(context, link);
			out.endElement("td");
		}

	}



	private Map getParamMap(FacesContext context) {
		return context.getExternalContext().getRequestParameterMap();
	}

	
	public String getOnClick(FacesContext context, UIComponent component,String value) {
		
		JSFunction function = AjaxRendererUtils.buildAjaxFunction(component,
				context);		
		UIDatascroller scroller=(UIDatascroller)component;
		Map eventOptions = AjaxRendererUtils.buildEventOptions(context,component);
		Map parameters = (Map) eventOptions.get("parameters");		
		parameters.put(scroller.getClientId(context) + PARAM_SUFFIX, value);
		function.addParameter(eventOptions);
		StringBuffer buffer = new StringBuffer();
		function.appendScript(buffer);		
		buffer.append("; return false;");
		String script = buffer.toString();
		return script;
	}
	
	
	/**
	 * Creates HtmlAjaxCommandLink sets its id, value and reRender and UIParameter
	 */
	public boolean getRendersChildren() {
		return true;
	}

}
