/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.taglib;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.el.ReferenceSyntaxException;
import javax.faces.el.ValueBinding;
import javax.faces.webapp.UIComponentTag;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.Tag;
import javax.servlet.jsp.tagext.TagSupport;

import org.ajax4jsf.dnd.event.DropListener;
import org.ajax4jsf.dnd.event.DropListenerBinding;
import org.ajax4jsf.dnd.event.DropSource;


/**
 * @author shura
 * 
 * Custom tag for append AJAX request listeners to AjaxContainer.
 *  
 */
public class DropListenerTag extends TagSupport {

    /**
     * 
     */
    private static final long serialVersionUID = 2576519366310474212L;
    /**
     * class name for ajax events listener.   
     */
    private String type = null;
    
    private String binding = null;
    
    private String dragType = null;

    /**
     *  
     */
    public DropListenerTag() {
    }

    public void setType(String type) {
        this.type = type;
    }

    /**
	 * @param binding the binding to set
	 */
	public void setBinding(String binding) {
		this.binding = binding;
	}

	/**
	 * @param dragType the dragType to set
	 */
	public void setDragType(String dragType) {
		this.dragType = dragType;
	}

	public int doStartTag() throws JspException {
        if (type == null && binding == null) {
            throw new JspException("dropListener tag must have one of 'type' or 'binding' attribute");
        }

        //Find parent UIComponentTag
        UIComponentTag componentTag = UIComponentTag
                .getParentUIComponentTag(pageContext);
        if (componentTag == null) {
            throw new JspException(
            		"Tag 'dropListener don't have any UIComponent provided ancestor tag");
        }

        if (componentTag.getCreated()) {
            //Component was just created, so we add the Listener
            UIComponent component = componentTag.getComponentInstance();
            if (component instanceof DropSource) {
                DropListener listener;
                if(null != binding){
                	ValueBinding valueBinding;
                	try {
					valueBinding = FacesContext.getCurrentInstance().getApplication().createValueBinding(binding);
                	} catch (ReferenceSyntaxException e) {
						throw new JspException(e);
					}
                	listener = new DropListenerBinding(valueBinding);
                } else {
                String className;
                if (UIComponentTag.isValueReference(type)) {
                    FacesContext facesContext = FacesContext
                            .getCurrentInstance();
                    ValueBinding valueBinding = facesContext.getApplication()
                            .createValueBinding(type);
                    className = (String) valueBinding.getValue(facesContext);
                } else {
                    className = type;
                }
				try {
					listener = (DropListener) Class.forName(className).newInstance();
				} catch (Exception e) {
	                throw new JspException("Error for create instance of Drop listener class "+ className, e);
				} 
                }
                ((DropSource) component).addDropListener(listener);
            } else {
                throw new JspException("Parent component is not instance of DropSource");
            }
        }

        return Tag.SKIP_BODY;
    }

}
